@@ -224,20 +224,60 @@ namespace PanoCommand
         return true;
     }
 
+    void UpdateSingleCtrlPointError(const HuginBase::Panorama& pano, HuginBase::ControlPoint& point)
+    {
+        HuginBase::UIntSet imgs;
+        imgs.insert(point.image1Nr);
+        imgs.insert(point.image2Nr);
+        HuginBase::Panorama copyPano = pano.duplicate();
+        HuginBase::CPVector cpVector;
+        // copy only the given cp to the duplicated pano
+        cpVector.push_back(point);
+        copyPano.setCtrlPoints(cpVector);
+        // create subpano with only images for the single cp
+        HuginBase::Panorama subPano = copyPano.getSubset(imgs);
+        // finally calc cp error
+        HuginBase::PTools::calcCtrlPointErrors(subPano);
+        point.error = subPano.getCtrlPoint(0).error;
+    }
+
     bool AddCtrlPointCmd::processPanorama(HuginBase::Panorama& pano)
     {
+        if (point.image1Nr > point.image2Nr)
+        {
+            // if the first image number is bigger than the second, mirror the point
+            point.mirror();
+        };
+        // calculate cp error only for newly added control point
+        UpdateSingleCtrlPointError(pano, point);
         pano.addCtrlPoint(point);
-        HuginBase::PTools::calcCtrlPointErrors(pano);
         return true;
     }
 
     bool AddCtrlPointsCmd::processPanorama(HuginBase::Panorama& pano)
     {
+        HuginBase::UIntSet imgs;
         for (HuginBase::CPVector::iterator it = cps.begin(); it != cps.end(); ++it)
         {
-            pano.addCtrlPoint(*it);
+            if ((*it).image1Nr > (*it).image2Nr)
+            {
+                (*it).mirror();
+            };
+            imgs.insert(it->image1Nr);
+            imgs.insert(it->image2Nr);
         }
-        HuginBase::PTools::calcCtrlPointErrors(pano);
+        // calculate cp error only for newly added control point
+        // create subpano with only images for the new cp
+        HuginBase::Panorama copyPano = pano.duplicate();
+        copyPano.setCtrlPoints(cps);
+        HuginBase::Panorama subPano = copyPano.getSubset(imgs);
+        // finally calc cp error
+        HuginBase::PTools::calcCtrlPointErrors(subPano);
+        for (auto it = cps.begin(); it != cps.end(); ++it)
+        {
+            it->error = subPano.getCtrlPoint(it - cps.begin()).error;
+            pano.addCtrlPoint(*it);
+        };
         return true;
     }
 
@@ -258,8 +298,10 @@ namespace PanoCommand
 
     bool ChangeCtrlPointCmd::processPanorama(HuginBase::Panorama& pano)
     {
+        // calculate cp error only for the changed control point
+        UpdateSingleCtrlPointError(pano, point);
+        // finally change the point
         pano.changeControlPoint(pNr, point);
-        HuginBase::PTools::calcCtrlPointErrors(pano);
         return true;
     }
 
