@@ -41,10 +41,10 @@
 class WXIMPEX RunStitchPanel: public wxPanel
 {
 public:
-    RunStitchPanel(wxWindow * parent);
+    explicit RunStitchPanel(wxWindow * parent);
 
-    bool StitchProject(wxString scriptFile, wxString outname);
-    bool DetectProject(wxString scriptFile);
+    bool StitchProject(const wxString& scriptFile, const wxString& outname, const wxString& userDefinedOutput = wxEmptyString);
+    bool DetectProject(const wxString& scriptFile);
     void CancelStitch();
 	bool IsPaused();
 	void SetOverwrite(bool over = true);
