@@ -373,6 +373,19 @@ namespace HuginQueue
             };
             return s;
         };
+
+        /** adds the command for the edge fill option */
+        void AddEdgeFillCommand(HuginQueue::CommandQueue* commands, const HuginBase::PanoramaOptions::EdgeFillMode& edgeFillMode, const wxString& ExePath, const wxString& inputFilename, const wxString& outputFilename, const wxString& compression)
+        {
+            if (edgeFillMode == HuginBase::PanoramaOptions::EDGE_FILL_SOLID)
+            {
+                commands->push_back(new NormalCommand(
+                    GetInternalProgram(ExePath, wxT("verdandi")),
+                    "--output=" + wxEscapeFilename(outputFilename) + " " + compression + " --seam=blend " + wxEscapeFilename(inputFilename),
+                    _("Filling edges...")));
+            }
+        }
+
     } // namespace detail
 
     CommandQueue* GetStitchingCommandQueue(const HuginBase::Panorama & pano, const wxString& ExePath, const wxString& project, const wxString& prefix, wxString& statusText, wxArrayString& outputFiles, wxArrayString& tempFilesDelete, std::ostream& errStream)
@@ -516,6 +529,8 @@ namespace HuginQueue
         };
         wxArrayString filesForFullExiftool;
         wxArrayString filesForCopyTagsExiftool;
+        // fill edge related options
+        const bool doEdgeFill = (opts.edgeFillMode != HuginBase::PanoramaOptions::NO_EDGE_FILL);
 
         // normal output
         if (opts.outputLDRBlended || opts.outputLDRLayers)
@@ -534,31 +549,52 @@ namespace HuginQueue
                     finalNonaArgs.Append(opts.verdandiOptions);
                     finalNonaArgs.Append(wxT(" "));
                 };
-                if (opts.outputImageType == "tif")
+                wxString edgeInputFile;
+                if (doEdgeFill)
                 {
-                    finalNonaArgs.Append(wxT("-m TIFF "));
-                    if (!opts.outputImageTypeCompression.empty())
+                    finalNonaArgs.Append("-m TIFF -z " + opts.tiffCompression + " --final-suffix=_nofill ");
+                    edgeInputFile = prefix + "_nofill.tif";
+                    outputFiles.Add(edgeInputFile);
+                    if (opts.keepEdgeFillInput)
                     {
-                        finalNonaArgs.Append(wxT("-z ") + opts.outputImageTypeCompression + wxT(" "));
+                        if (copyMetadata)
+                        {
+                            filesForFullExiftool.Add(edgeInputFile);
+                        };
+                    }
+                    else
+                    {
+                        tempFilesDelete.Add(edgeInputFile);
                     };
                 }
                 else
                 {
-                    if (opts.outputImageType == "jpg")
+                    if (opts.outputImageType == "tif")
                     {
-                        finalNonaArgs.Append(wxT("-m JPEG -z "));
-                        finalNonaArgs << opts.quality << wxT(" ");
+                        finalNonaArgs.Append(wxT("-m TIFF "));
+                        if (!opts.outputImageTypeCompression.empty())
+                        {
+                            finalNonaArgs.Append(wxT("-z ") + opts.outputImageTypeCompression + wxT(" "));
+                        };
                     }
                     else
                     {
-                        if (opts.outputImageType == "png")
+                        if (opts.outputImageType == "jpg")
                         {
-                            finalNonaArgs.Append(wxT("-m PNG "));
+                            finalNonaArgs.Append(wxT("-m JPEG -z "));
+                            finalNonaArgs << opts.quality << wxT(" ");
                         }
                         else
                         {
-                            errStream << "ERROR: Invalid output image type found." << std::endl;
-                            return commands;
+                            if (opts.outputImageType == "png")
+                            {
+                                finalNonaArgs.Append(wxT("-m PNG "));
+                            }
+                            else
+                            {
+                                errStream << "ERROR: Invalid output image type found." << std::endl;
+                                return commands;
+                            };
                         };
                     };
                 };
@@ -571,6 +607,10 @@ namespace HuginQueue
                 commands->push_back(new NormalCommand(GetInternalProgram(ExePath, wxT("nona")),
                     finalNonaArgs, _("Remapping and blending LDR images...")));
                 outputFiles.Add(finalFilename);
+                if (doEdgeFill)
+                {
+                    detail::AddEdgeFillCommand(commands, opts.edgeFillMode, ExePath, edgeInputFile, finalFilename, finalCompressionArgs);
+                };
                 if (copyMetadata)
                 {
                     filesForFullExiftool.Add(finalFilename);
@@ -586,16 +626,38 @@ namespace HuginQueue
                 {
                     if (opts.blendMode == HuginBase::PanoramaOptions::ENBLEND_BLEND)
                     {
-                        wxString finalEnblendArgs(enblendArgs + finalCompressionArgs);
-                        finalEnblendArgs.Append(wxT(" -o ") + wxEscapeFilename(finalFilename) + wxT(" -- "));
+                        wxString finalEnblendArgs(enblendArgs);
+                        wxString edgeFillInput;
+                        if (doEdgeFill)
+                        {
+                            edgeFillInput = prefix + "_nofill.tif";
+                            finalEnblendArgs.Append("--compression=" + opts.tiffCompression + " -o " + wxEscapeFilename(edgeFillInput) + " -- ");
+                        }
+                        else
+                        {
+                            finalEnblendArgs.Append(finalCompressionArgs + wxT(" -o ") + wxEscapeFilename(finalFilename) + wxT(" -- "));
+                        };
                         commands->push_back(new NormalCommand(
                             GetExternalProgram(config, ExePath, wxT("enblend")), 
                             finalEnblendArgs + wxT(" ") + GetQuotedFilenamesString(remappedImages), 
                             _("Blending images..."))
                         );
+                        if (doEdgeFill)
+                        {
+                            detail::AddEdgeFillCommand(commands, opts.edgeFillMode, ExePath, edgeFillInput, finalFilename, finalCompressionArgs);
+                            outputFiles.Add(edgeFillInput);
+                            if (!opts.keepEdgeFillInput)
+                            {
+                                tempFilesDelete.Add(edgeFillInput);
+                            };
+                        };
                         outputFiles.Add(finalFilename);
                         if (copyMetadata)
                         {
+                            if (doEdgeFill && opts.keepEdgeFillInput)
+                            {
+                                filesForFullExiftool.Add(edgeFillInput);
+                            };
                             filesForFullExiftool.Add(finalFilename);
                         };
                     };
@@ -693,17 +755,39 @@ namespace HuginQueue
             };
             if (opts.outputLDRExposureLayersFused)
             {
-                wxString finalEnfuseArgs(enfuseArgs + finalCompressionArgs);
                 const wxString fusedExposureLayersFilename(prefix + wxT("_blended_fused.") + opts.outputImageType);
-                finalEnfuseArgs.Append(wxT(" -o ") + wxEscapeFilename(fusedExposureLayersFilename) + wxT(" -- "));
+                wxString finalEnfuseArgs(enfuseArgs);
+                wxString edgeFillInput;
+                if (doEdgeFill)
+                {
+                    edgeFillInput = prefix + "_blended_fused_nofill.tif";
+                    finalEnfuseArgs.Append("--compression=" + opts.tiffCompression + " -o " + wxEscapeFilename(edgeFillInput) + " -- ");
+                }
+                else
+                {
+                    finalEnfuseArgs.Append(finalCompressionArgs + wxT(" -o ") + wxEscapeFilename(fusedExposureLayersFilename) + wxT(" -- "));
+                };
                 commands->push_back(new NormalCommand(
                     GetExternalProgram(config, ExePath, wxT("enfuse")),
                     finalEnfuseArgs + wxT(" ")+GetQuotedFilenamesString(exposureLayersFiles), 
                     _("Fusing all exposure layers..."))
                 );
                 outputFiles.Add(fusedExposureLayersFilename);
+                if (doEdgeFill)
+                {
+                    detail::AddEdgeFillCommand(commands, opts.edgeFillMode, ExePath, edgeFillInput, fusedExposureLayersFilename, finalCompressionArgs);
+                    outputFiles.Add(edgeFillInput);
+                    if (!opts.keepEdgeFillInput)
+                    {
+                        tempFilesDelete.Add(edgeFillInput);
+                    };
+                };
                 if (copyMetadata)
                 {
+                    if (doEdgeFill && opts.keepEdgeFillInput)
+                    {
+                        filesForFullExiftool.Add(edgeFillInput);
+                    };
                     filesForFullExiftool.Add(fusedExposureLayersFilename);
                 };
             };
@@ -736,12 +820,24 @@ namespace HuginQueue
                 if (opts.outputLDRExposureBlended)
                 {
                     const wxString fusedStacksFilename(prefix + wxT("_fused.") + opts.outputImageType);
+                    wxString edgeFillInput;
+                    if (doEdgeFill)
+                    {
+                        edgeFillInput = prefix + "_fused_nofill.tif";
+                    };
                     switch (opts.blendMode)
                     {
                     case HuginBase::PanoramaOptions::ENBLEND_BLEND:
                         {
-                            wxString finalEnblendArgs(enblendArgs + finalCompressionArgs);
-                            finalEnblendArgs.Append(wxT(" -o ") + wxEscapeFilename(fusedStacksFilename) + wxT(" -- "));
+                            wxString finalEnblendArgs(enblendArgs);
+                            if (doEdgeFill)
+                            {
+                                finalEnblendArgs.Append("--compression=" + opts.tiffCompression + " -o " + wxEscapeFilename(edgeFillInput) + "-- ");
+                            }
+                            else
+                            {
+                                finalEnblendArgs.Append(finalCompressionArgs + wxT(" -o ") + wxEscapeFilename(fusedStacksFilename) + wxT(" -- "));
+                            };
                             commands->push_back(new NormalCommand(
                                 GetExternalProgram(config, ExePath, wxT("enblend")),
                                 finalEnblendArgs+wxT(" ")+GetQuotedFilenamesString(stackedImages), 
@@ -752,8 +848,15 @@ namespace HuginQueue
                     case HuginBase::PanoramaOptions::INTERNAL_BLEND:
                     default:  // switch to internal blender for all other cases, not exposed in GUI
                         {
-                            wxString finalVerdandiArgs(verdandiArgs + finalCompressionArgs);
-                            finalVerdandiArgs.Append(wxT(" -o ") + wxEscapeFilename(fusedStacksFilename));
+                            wxString finalVerdandiArgs(verdandiArgs); 
+                            if (doEdgeFill)
+                            {
+                                finalVerdandiArgs.Append("--compression=" + opts.tiffCompression + " -o" + wxEscapeFilename(edgeFillInput));
+                            }
+                            else
+                            {
+                                finalVerdandiArgs.Append(finalCompressionArgs + wxT(" -o ") + wxEscapeFilename(fusedStacksFilename));
+                            };
                             finalVerdandiArgs.Append(wxT(" -- ") + detail::GetQuotedFilenamesStringForVerdandi(stackedImages, pano, stacks, opts.colorReferenceImage, opts.verdandiOptions.find("--seam=blend") == std::string::npos));
                             commands->push_back(new NormalCommand(GetInternalProgram(ExePath, wxT("verdandi")),
                                 finalVerdandiArgs, _("Blending all stacks...")));
@@ -761,8 +864,21 @@ namespace HuginQueue
                         break;
                     };
                     outputFiles.Add(fusedStacksFilename);
+                    if (doEdgeFill)
+                    {
+                        detail::AddEdgeFillCommand(commands, opts.edgeFillMode, ExePath, edgeFillInput, fusedStacksFilename, finalCompressionArgs);
+                        outputFiles.Add(edgeFillInput);
+                        if (!opts.keepEdgeFillInput)
+                        {
+                            tempFilesDelete.Add(edgeFillInput);
+                        };
+                    };
                     if (copyMetadata)
                     {
+                        if (doEdgeFill && opts.keepEdgeFillInput)
+                        {
+                            filesForFullExiftool.Add(edgeFillInput);
+                        };
                         filesForFullExiftool.Add(fusedStacksFilename);
                     };
                 };
@@ -804,7 +920,17 @@ namespace HuginQueue
                 if (opts.outputHDRBlended)
                 {
                     const wxString mergedStacksFilename(prefix + wxT("_hdr.") + opts.outputImageTypeHDR);
-                    wxString finalBlendArgs(wxT(" -o ") + wxEscapeFilename(mergedStacksFilename) + wxT(" -- "));
+                    wxString finalBlendArgs;
+                    wxString edgeFillInput;
+                    if (doEdgeFill)
+                    {
+                        edgeFillInput = prefix + "_hdr_nofill.exr";
+                        finalBlendArgs.Append(wxT(" -o ") + wxEscapeFilename(edgeFillInput) + wxT(" -- "));
+                    }
+                    else
+                    {
+                        finalBlendArgs.Append(wxT(" -o ") + wxEscapeFilename(mergedStacksFilename) + wxT(" -- "));
+                    };
                     switch (opts.blendMode)
                     {
                         case HuginBase::PanoramaOptions::ENBLEND_BLEND:
@@ -822,8 +948,21 @@ namespace HuginQueue
                             break;
                     };
                     outputFiles.Add(mergedStacksFilename);
+                    if (doEdgeFill)
+                    {
+                        detail::AddEdgeFillCommand(commands, opts.edgeFillMode, ExePath, edgeFillInput, mergedStacksFilename, finalCompressionArgs);
+                        outputFiles.Add(edgeFillInput);
+                        if (!opts.keepEdgeFillInput)
+                        {
+                            tempFilesDelete.Add(edgeFillInput);
+                        };
+                    };
                     if (copyMetadata)
                     {
+                        if (doEdgeFill && opts.keepEdgeFillInput)
+                        {
+                            filesForFullExiftool.Add(edgeFillInput);
+                        };
                         filesForFullExiftool.Add(mergedStacksFilename);
                     };
                 };
