@@ -209,7 +209,7 @@ std::string GetICCProfileNameChecked(const std::string& iccName)
     };
     // all profiles starting with sRGB are assumed the same
     // even if there small? differences between them
-    if (iccName.compare(0, 3, "sRGB") == 0)
+    if (iccName.compare(0, 4, "sRGB") == 0)
     {
         return "sRGB";
     };
@@ -365,6 +365,11 @@ bool wxAddImagesCmd::processPanorama(HuginBase::Panorama& pano)
                 srcImg.readProjectionFromDB(ignoreFovRectilinear);
             };
         };
+        // set preferred projection if requested
+        if (m_preferredLensType != -1)
+        {
+            srcImg.setProjection(static_cast<HuginBase::BaseSrcPanoImage::Projection>(m_preferredLensType));
+        };
         // save EXIF data for later to prevent double loading of EXIF data
         applyColorBalanceValue(srcImg, pano);
         if (! ok ) {
@@ -424,6 +429,8 @@ bool wxAddImagesCmd::processPanorama(HuginBase::Panorama& pano)
                     && other.getExifModel() == srcImg.getExifModel()
                     && other.getExifMake()  == srcImg.getExifMake()
                     && other.getExifFocalLength() == srcImg.getExifFocalLength()
+                    // Smartphone cameras can have different crop factors, take also this case into account
+                    && other.getCropFactor() == srcImg.getCropFactor()
                    )
                 {
                     matchingLensNr = lenses.getPartNumber(i);
@@ -563,6 +570,7 @@ bool wxLoadPTProjectCmd::processPanorama(HuginBase::Panorama& pano)
         wxString basedir;
         bool autopanoSiftFile=false;
         HuginBase::SrcPanoImage autopanoSiftRefImg;
+        HuginBase::VariableMapVector vars(nImg);
         for (unsigned int i = 0; i < nImg; i++) {
             wxFileName fname(wxString (pano.getImage(i).getFilename().c_str(), HUGIN_CONV_FILENAME));
             while (! fname.FileExists()){
@@ -615,7 +623,7 @@ bool wxLoadPTProjectCmd::processPanorama(HuginBase::Panorama& pano)
             vigra::ImageImportInfo imginfo(srcImg.getFilename().c_str());
             if (srcImg.getSize() != imginfo.size()) {
                 // adjust size properly.
-                srcImg.resize(imginfo.size());
+                srcImg.resize(imginfo.size(), &vars[i]);
             }
             // check if script contains invalid HFOV
             double hfov = pano.getImage(i).getHFOV();
@@ -651,6 +659,15 @@ bool wxLoadPTProjectCmd::processPanorama(HuginBase::Panorama& pano)
             }
             pano.setSrcImage(i, srcImg);
         }
+        // special update routine, when images size changed
+        // and some linked variables needs update after rescaling
+        for (unsigned i = 0; i < nImg; ++i)
+        {
+            if (!vars[i].empty())
+            {
+                pano.updateVariables(i, vars[i]);
+            };
+        };
         // Link image projection across each lens, since it is not saved.
         const HuginBase::UIntSetVector imgSetLens = lenses.getPartsSet();
         for (size_t i = 0; i < imgSetLens.size(); ++i)
@@ -871,6 +888,7 @@ bool wxApplyTemplateCmd::processPanorama(HuginBase::Panorama& pano)
         }
 
         // check image sizes, and correct parameters if required.
+        HuginBase::VariableMapVector vars(nNewImg);
         for (unsigned int i = 0; i < nNewImg; i++) {
 
             // check if image size is correct
@@ -882,10 +900,20 @@ bool wxApplyTemplateCmd::processPanorama(HuginBase::Panorama& pano)
             newSrcImg.setFilename(oldSrcImg.getFilename());
             if (oldSrcImg.getSize() != newSrcImg.getSize()) {
                 // adjust size properly.
-                newSrcImg.resize(oldSrcImg.getSize());
+                newSrcImg.resize(oldSrcImg.getSize(), &(vars[i]));
             }
             newPano.setSrcImage(i, newSrcImg);
         }
+        // now update all possible linked variables
+        // this has to be done separately, otherwise the linked variables
+        // would be updated several times
+        for (unsigned int i = 0; i < nNewImg; ++i)
+        {
+            if (!vars[i].empty())
+            {
+                newPano.updateVariables(i, vars[i]);
+            };
+        };
         // keep old control points.
         newPano.setCtrlPoints(pano.getCtrlPoints());
         newPanoMem = newPano.getMemento();
