@@ -50,13 +50,14 @@ namespace PanoCommand
     class WXIMPEX wxAddImagesCmd : public PanoCommand
     {
     public:
-        wxAddImagesCmd(HuginBase::Panorama & pano, const std::vector<std::string> & newfiles)
-            : PanoCommand(pano), files(newfiles)
+        wxAddImagesCmd(HuginBase::Panorama & pano, const std::vector<std::string> & newfiles, const int preferredLensType=-1)
+            : PanoCommand(pano), files(newfiles), m_preferredLensType(preferredLensType)
         { };
         virtual bool processPanorama(HuginBase::Panorama& pano);
         virtual std::string getName() const { return "add images"; };
     private:
         std::vector<std::string> files;
+        int m_preferredLensType;
     };
 
     /** dump the current project and load a new one.
