@@ -480,9 +480,11 @@ void LensCalFrame::OnRemoveImage(wxCommandEvent &e)
     int selection=m_images_list->GetSelection();
     if(selection!=wxNOT_FOUND)
     {
+        // remove file from cache
+        const std::string filename(m_images[selection]->GetFilename().mb_str(HUGIN_CONV_FILENAME));
+        ImageCache::getInstance().removeImage(filename);
         delete m_images[selection];
         m_images.erase(m_images.begin()+selection);
-        ImageCache::getInstance().softFlush();
         UpdateList(false);
     }
     else
