@@ -170,7 +170,7 @@ void DrawCross(wxDC& dc, wxPoint p, int l)
                 p + wxPoint(0, l+1));
 };
 
-void DisplayedControlPoint::Draw(wxDC& dc, bool selected, bool newPoint)
+void DisplayedControlPoint::Draw(wxDC& dc, const wxRect& visibleRect, bool selected, bool newPoint)
 {
     if(m_control==NULL)
     {
@@ -201,16 +201,36 @@ void DisplayedControlPoint::Draw(wxDC& dc, bool selected, bool newPoint)
     wxPoint p = m_control->roundP(m_control->scale(point));
     hugin_utils::FDiff2D pointInput2;
     wxPoint p2;
-    if(m_line)
+    if(IsDrawingLine())
     {
         pointInput2=m_mirrored ? hugin_utils::FDiff2D(m_cp.x1, m_cp.y1) : hugin_utils::FDiff2D(m_cp.x2, m_cp.y2);
         hugin_utils::FDiff2D point2 = m_control->applyRot(pointInput2);
         p2 = m_control->roundP(m_control->scale(point2));
-    };
+        // check that line is in visible range
+        const wxRect lineRect(p, p2);
+        if (!visibleRect.Intersects(lineRect))
+        {
+            // reset label position, so it is not considered when checking
+            m_labelPos = wxRect();
+            m_labelPos2 = wxRect();
+            return;
+        };
+    }
+    else
+    {
+        // check that point is inside the visible rect
+        if (!visibleRect.Contains(p))
+        {
+            // reset label position, so it is not considered when checking
+            m_labelPos = wxRect();
+            m_labelPos2 = wxRect();
+            return;
+        };
+    }
     int l = 6;
     // draw cursor line, choose white or black
     vigra::Rect2D box;
-    if(m_line)
+    if(IsDrawingLine())
     {
         box.setUpperLeft(vigra::Point2D(hugin_utils::roundi(std::min(m_cp.x1, m_cp.x2)) - l, hugin_utils::roundi(std::min(m_cp.y1, m_cp.y2)) - l));
         box.setSize(hugin_utils::roundi(std::abs(m_cp.x1 - m_cp.x2) + 2.0*l), hugin_utils::roundi(std::abs(m_cp.y1 - m_cp.y2) + 2.0*l));
@@ -241,7 +261,7 @@ void DisplayedControlPoint::Draw(wxDC& dc, bool selected, bool newPoint)
         dc.SetPen(wxPen(wxT("BLACK"), 1, wxPENSTYLE_SOLID));
     }
 
-    if(m_line)
+    if(IsDrawingLine())
     {
         DrawLine(dc);
         DrawCross(dc, p, l);
@@ -249,7 +269,7 @@ void DisplayedControlPoint::Draw(wxDC& dc, bool selected, bool newPoint)
     }
     else
     {
-        if (m_cp.mode != HuginBase::ControlPoint::X_Y)
+        if (m_cp.mode != HuginBase::ControlPoint::X_Y && m_control->IsShowingLines())
         {
             DrawLineSegment(dc);
         };
@@ -257,11 +277,12 @@ void DisplayedControlPoint::Draw(wxDC& dc, bool selected, bool newPoint)
     };
     // calculate distance to the image boundaries,
     // decide where to put the label and magnifier
-    m_labelPos=DrawTextMag(dc, p, pointInput, drawMag, textColor, bgColor);
-    if(m_line)
+    if (IsDrawingLine())
     {
-        m_labelPos2=DrawTextMag(dc, p2, pointInput2, drawMag, textColor, bgColor);
+        m_labelPos2 = DrawTextMag(dc, p2, pointInput2, drawMag, textColor, bgColor);
     };
+    // draw first point second so that is on top
+    m_labelPos=DrawTextMag(dc, p, pointInput, drawMag, textColor, bgColor);
 }
 
 wxRect DisplayedControlPoint::DrawTextMag(wxDC& dc, wxPoint p, hugin_utils::FDiff2D pointInput, bool drawMag, wxColour textColour, wxColour bgColour)
@@ -292,7 +313,7 @@ wxRect DisplayedControlPoint::DrawTextMag(wxDC& dc, wxPoint p, hugin_utils::FDif
 
     if (drawMag && m_control->getScale() < 2)
     {
-        wxBitmap magBitmap = m_control->generateMagBitmap(pointInput, p);
+        const wxBitmap& magBitmap = m_control->GetMagBitmap(pointInput);
         // TODO: select position depending on visible part of canvas
         wxPoint ulMag = tul;
         // choose placement of the magnifier
@@ -488,9 +509,14 @@ void DisplayedControlPoint::DrawLineSegment(wxDC& dc)
     delete []points;
 };
 
+bool DisplayedControlPoint::IsDrawingLine() const
+{
+    return m_line && m_control->IsShowingLines();
+}
+
 const bool DisplayedControlPoint::isOccupiedLabel(const wxPoint mousePos) const
 {
-    if(m_line)
+    if(IsDrawingLine())
     {
         return m_labelPos.Contains(mousePos) || m_labelPos2.Contains(mousePos);
     }
@@ -503,7 +529,7 @@ const bool DisplayedControlPoint::isOccupiedLabel(const wxPoint mousePos) const
 const bool DisplayedControlPoint::isOccupiedPos(const hugin_utils::FDiff2D &p) const
 {
     double d=m_control->invScale(3.0);
-    if(m_line)
+    if(IsDrawingLine())
     {
         return (p.x < m_cp.x1 + d && p.x > m_cp.x1 - d && p.y < m_cp.y1 + d && p.y > m_cp.y1 - d) ||
                (p.x < m_cp.x2 + d && p.x > m_cp.x2 - d && p.y < m_cp.y2 + d && p.y > m_cp.y2 - d);
@@ -523,7 +549,7 @@ const bool DisplayedControlPoint::isOccupiedPos(const hugin_utils::FDiff2D &p) c
 
 void DisplayedControlPoint::CheckSelection(const wxPoint mousePos, const hugin_utils::FDiff2D& p)
 {
-    if(!m_line)
+    if(!IsDrawingLine())
     {
         return;
     };
@@ -625,6 +651,11 @@ BEGIN_EVENT_TABLE(CPImageCtrl, wxScrolledWindow)
     EVT_MIDDLE_DOWN(CPImageCtrl::mousePressMMBEvent)
     EVT_MIDDLE_UP(CPImageCtrl::mouseReleaseMMBEvent)
     EVT_TIMER(-1, CPImageCtrl::OnTimer)
+#ifdef __WXMSW__
+    // update view after scrolling on Windows
+    // on WXGTK this is handled already by the control
+    EVT_SCROLLWIN(CPImageCtrl::OnScrollWin)
+#endif
 END_EVENT_TABLE()
 
 bool CPImageCtrl::Create(wxWindow * parent, wxWindowID id,
@@ -645,6 +676,7 @@ bool CPImageCtrl::Create(wxWindow * parent, wxWindowID id,
     m_editPanel = 0;
     m_imgRotation = ROT0;
     m_sameImage = false;
+    m_magImgCenter = hugin_utils::FDiff2D(-1, -1);
 
     wxString filename;
 
@@ -695,6 +727,7 @@ void CPImageCtrl::Init(CPEditorPanel * parent)
 {
     m_editPanel = parent;
     m_sameImage = false;
+    m_magImgCenter = hugin_utils::FDiff2D(-1, -1);
 }
 
 CPImageCtrl::~CPImageCtrl()
@@ -734,11 +767,13 @@ void CPImageCtrl::OnDraw(wxDC & dc)
 	}
 
     // draw known points.
+    wxRect visibleRect(GetViewStart(), vSize);
+    visibleRect.Inflate(20);
     for(size_t i=0; i<m_points.size(); i++)
     {
         if (!(editState == KNOWN_POINT_SELECTED && i==selectedPointNr))
         {
-            m_points[i].Draw(dc, false);
+            m_points[i].Draw(dc, visibleRect, false);
         };
     }
 
@@ -752,7 +787,7 @@ void CPImageCtrl::OnDraw(wxDC & dc)
         {
             DisplayedControlPoint dsp(HuginBase::ControlPoint(0, newPoint.x, newPoint.y, 0, 0, 0), this, false);
             dsp.SetLabel(_("new"));
-            dsp.Draw(dc, false, true);
+            dsp.Draw(dc, visibleRect, false, true);
         }
         if (m_showTemplateArea) {
             dc.SetLogicalFunction(wxINVERT);
@@ -769,10 +804,10 @@ void CPImageCtrl::OnDraw(wxDC & dc)
 
         break;
     case NEW_LINE_CREATING:
-        m_selectedPoint.Draw(dc, false, true);
+        m_selectedPoint.Draw(dc, visibleRect, false, true);
         break;
     case KNOWN_POINT_SELECTED:
-        m_points[selectedPointNr].Draw(dc, true);
+        m_points[selectedPointNr].Draw(dc, visibleRect, true);
         break;
     case SELECT_DELETE_REGION:
     case NO_SELECTION:
@@ -795,61 +830,45 @@ void CPImageCtrl::OnDraw(wxDC & dc)
     }
 }
 
-class ScalingTransform
+wxBitmap& CPImageCtrl::GetMagBitmap(hugin_utils::FDiff2D point)
 {
-public:
-    explicit ScalingTransform(double scale)
-    : m_scale(scale) {};
-
-    bool transformImgCoord(double & sx, double & sy, double x, double y)
+    if (m_magImgCenter == point)
     {
-        sx = m_scale*x;
-        sy = m_scale*y;
-        return true;
-    }
-
-    double m_scale;
-};
-
-wxBitmap CPImageCtrl::generateMagBitmap(hugin_utils::FDiff2D point, wxPoint canvasPos) const
-{
+        // if point has not moved use cached image
+        return m_magImg;
+    };
+    // point has changed, we need to recalculate the magnified image
     typedef vigra::RGBValue<vigra::UInt8> VT;
     DEBUG_TRACE("")
 
-    // draw magnified image (TODO: warp!)
-    double magScale = 3.0;
-    wxConfigBase::Get()->Read(wxT("/CPEditorPanel/MagnifierScale"), &magScale);
+    // draw magnified image
     // width (and height) of magnifier region (output), should be odd
     int magWidth = wxConfigBase::Get()->Read(wxT("/CPEditorPanel/MagnifierWidth"),61l);
     int hw = magWidth/2;
     magWidth = hw*2+1;
 
-    // setup simple scaling transformation function.
-    ScalingTransform transform(1.0/magScale);
-    ScalingTransform invTransform(magScale);
     wxImage img(magWidth, magWidth);
     vigra::BasicImageView<VT> magImg((VT*)img.GetData(), magWidth,magWidth);
     vigra::BImage maskImg(magWidth, magWidth);
     vigra_ext::PassThroughFunctor<vigra::UInt8> ptf;
 
-
     // middle pixel
     double mx, my;
-    invTransform.transformImgCoord(mx, my, point.x, point.y);
+    m_magInvTrans->transformImgCoord(mx, my, point.x, point.y);
 
-    // apply the transform
+    // apply the transform, for the small window the multithreading has too much overhead, so use only single threaded version
     AppBase::DummyProgressDisplay progDisp;
     vigra_ext::transformImageIntern(vigra::srcImageRange(*m_img->get8BitImage()),
                          vigra::destImageRange(magImg),
                          vigra::destImage(maskImg),
-                         transform,
+                         *m_magTrans,
                          ptf,
                          vigra::Diff2D(hugin_utils::roundi(mx - hw),
                                        hugin_utils::roundi(my - hw)),
                          vigra_ext::interp_cubic(),
                          false,
                          &progDisp,
-                         false);
+                         true);
 
     // TODO: contrast enhancement
     vigra::FindMinMax<vigra::UInt8> minmax;
@@ -881,22 +900,23 @@ wxBitmap CPImageCtrl::generateMagBitmap(hugin_utils::FDiff2D point, wxPoint canv
     }
 
     // rotate image according to current display
-    switch(m_imgRotation) {
+    switch (m_imgRotation) {
         case ROT90:
             img = img.Rotate90(true);
             break;
         case ROT180:
-            // this is slower than it needs to be...
-            img = img.Rotate90(true);
-            img = img.Rotate90(true);
+            img = img.Rotate180();
             break;
         case ROT270:
             img = img.Rotate90(false);
             break;
         default:
             break;
-    }
-    return wxBitmap (img);
+    };
+
+    m_magImg = wxBitmap(img);
+    m_magImgCenter = point;
+    return m_magImg;
 }
 
 wxSize CPImageCtrl::DoGetBestSize() const
@@ -910,6 +930,7 @@ void CPImageCtrl::setImage(const std::string & file, ImageRotation imgRot)
     DEBUG_TRACE("setting Image " << file);
     imageFilename = file;
     m_sameImage=false;
+    m_magImgCenter = hugin_utils::FDiff2D(-1, -1);
     wxString fn(imageFilename.c_str(),HUGIN_CONV_FILENAME);
     if (wxFileName::FileExists(fn)) {
         m_imgRotation = imgRot;
@@ -941,6 +962,12 @@ void CPImageCtrl::setTransforms(HuginBase::PTools::Transform* firstTrans, HuginB
     m_secondInvTrans=secondInvTrans;
 };
 
+void CPImageCtrl::setMagTransforms(HuginBase::PTools::Transform* magTrans, HuginBase::PTools::Transform* magInvTrans)
+{
+    m_magTrans = magTrans;
+    m_magInvTrans = magInvTrans;
+}
+
 void CPImageCtrl::setSameImage(bool sameImage)
 {
     m_sameImage=sameImage;
@@ -1004,9 +1031,7 @@ void CPImageCtrl::rescaleImage()
                 img = img.Rotate90(true);
                 break;
             case ROT180:
-                // this is slower than it needs to be...
-                img = img.Rotate90(true);
-                img = img.Rotate90(true);
+                img = img.Rotate180();
                 break;
             case ROT270:
                 img = img.Rotate90(false);
@@ -1058,13 +1083,17 @@ void CPImageCtrl::clearNewPoint()
 }
 
 
-void CPImageCtrl::selectPoint(unsigned int nr)
+void CPImageCtrl::selectPoint(unsigned int nr, bool scrollTo)
 {
     DEBUG_TRACE("nr: " << nr);
     if (nr < m_points.size()) {
         selectedPointNr = nr;
         editState = KNOWN_POINT_SELECTED;
-        showPosition(m_points[nr].GetPos());
+        if (scrollTo)
+        {
+            // scroll to center only when requested
+            showPosition(m_points[nr].GetPos());
+        };
         update();
     } else {
         DEBUG_DEBUG("trying to select invalid point nr: " << nr << ". Nr of points: " << m_points.size());
@@ -1133,8 +1162,9 @@ void CPImageCtrl::DrawSelectionRectangle(hugin_utils::FDiff2D pos1,hugin_utils::
 {
     wxClientDC dc(this);
     PrepareDC(dc);
-    dc.SetLogicalFunction(wxINVERT);
-    dc.SetPen(wxPen(*wxWHITE,1, wxPENSTYLE_DOT));
+    wxDCOverlay overlaydc(m_overlay, &dc);
+    overlaydc.Clear();
+    dc.SetPen(wxPen(*wxWHITE, 2, wxPENSTYLE_LONG_DASH));
     dc.SetBrush(*wxTRANSPARENT_BRUSH);
     wxPoint p1=roundP(scale(applyRot(pos1)));
     wxPoint p2=roundP(scale(applyRot(pos2)));
@@ -1204,12 +1234,12 @@ void CPImageCtrl::mouseMoveEvent(wxMouseEvent& mouse)
     if ((mouse.MiddleIsDown() || mouse.ShiftDown() || mouse.m_controlDown ) && editState!=SELECT_DELETE_REGION) {
         // scrolling with the mouse
         if (m_mouseScrollPos !=mouse.GetPosition()) {
-            wxPoint delta_ = mouse.GetPosition() - m_mouseScrollPos;
-            double speed = (double)GetVirtualSize().GetHeight() / GetClientSize().GetHeight();
-//          int speed = wxConfigBase::Get()->Read(wxT("/CPEditorPanel/scrollSpeed"),5);
-            wxPoint delta;
-            delta.x = hugin_utils::roundi(delta_.x * speed);
-            delta.y =  hugin_utils::roundi(delta_.y * speed);
+            wxPoint delta = mouse.GetPosition() - m_mouseScrollPos;
+            if (mouse.MiddleIsDown())
+            {
+                // invert scroll direction for middle mouse click (touchpad like scrolling)
+                delta = -delta;
+            };
             // scrolling is done later
             if (mouse.ShiftDown()) {
                 // emit scroll event, so that other window can be scrolled
@@ -1227,7 +1257,6 @@ void CPImageCtrl::mouseMoveEvent(wxMouseEvent& mouse)
     if(mouse.RightIsDown() && editState==SELECT_DELETE_REGION)
     {
         //update selection rectangle
-        DrawSelectionRectangle(rectStartPos,m_mousePos);
         DrawSelectionRectangle(rectStartPos,mpos);
     }
 //    DEBUG_DEBUG("ImageDisplay: mouse move, state: " << editState);
@@ -1238,8 +1267,7 @@ void CPImageCtrl::mouseMoveEvent(wxMouseEvent& mouse)
     }
 
     unsigned int selPointNr;
-    if (isOccupied(unScrolledMousePos, mpos, selPointNr) == KNOWN_POINT_SELECTED &&
-        (! (editState == KNOWN_POINT_SELECTED && selectedPointNr == selPointNr) ) ) {
+    if (isOccupied(unScrolledMousePos, mpos, selPointNr) == KNOWN_POINT_SELECTED ) {
         SetCursor(wxCursor(wxCURSOR_ARROW));
     } else {
         SetCursor(*m_CPSelectCursor);
@@ -1283,7 +1311,10 @@ void CPImageCtrl::mousePressLMBEvent(wxMouseEvent& mouse)
             m_points[selectedPointNr].CheckSelection(unScrolledMousePos, mpos);
             m_selectedPoint = m_points[selectedPointNr];
             editState = clickState;
+            // notify parent and therefore other CPImageCtrl to select the clicked point
             CPEvent e( this, selectedPointNr);
+            // stop timer so that magnifier is always displayed when moving cp and not hidden by timer
+            m_timer.Stop();
             m_forceMagnifier = true;
             emit(e);
         } else if (clickState == NEW_POINT_SELECTED) {
@@ -1315,6 +1346,13 @@ void CPImageCtrl::OnTimer(wxTimerEvent & e)
     update();
 }
 
+void CPImageCtrl::OnScrollWin(wxScrollWinEvent& e)
+{
+    // repaint image, so that labels and magnifier are updated
+    update();
+    e.Skip();
+}
+
 void CPImageCtrl::mouseReleaseLMBEvent(wxMouseEvent& mouse)
 {
     DEBUG_DEBUG("LEFT MOUSE UP");
@@ -1345,6 +1383,8 @@ void CPImageCtrl::mouseReleaseLMBEvent(wxMouseEvent& mouse)
         case KNOWN_POINT_SELECTED:
         {
             DEBUG_DEBUG("mouse release with known point " << selectedPointNr);
+            // scroll so that currently selected point is centered
+            showPosition(m_selectedPoint.GetPos());
             if (! (m_selectedPoint == m_points[selectedPointNr]) ) {
                 CPEvent e( this, CPEvent::POINT_CHANGED, selectedPointNr, m_points[selectedPointNr].GetControlPoint());
                 emit(e);
@@ -1411,7 +1451,6 @@ void CPImageCtrl::mousePressRMBEvent(wxMouseEvent& mouse)
     {
         rectStartPos=mpos;
         editState=SELECT_DELETE_REGION;
-        DrawSelectionRectangle(mpos,mpos);
     };
 };
 
@@ -1430,7 +1469,14 @@ void CPImageCtrl::mouseReleaseRMBEvent(wxMouseEvent& mouse)
     {
         if(editState==SELECT_DELETE_REGION)
         {
-            DrawSelectionRectangle(rectStartPos,mpos);
+            // clear overlay
+            {
+                wxClientDC dc(this);
+                PrepareDC(dc);
+                wxDCOverlay overlaydc(m_overlay, &dc);
+                overlaydc.Clear();
+                m_overlay.Reset();
+            };
             editState=NO_SELECTION;
             CPEvent e(this,rectStartPos,mpos);
             emit(e);
@@ -1747,6 +1793,12 @@ void CPImageCtrl::ScrollDelta(const wxPoint & delta)
     if (x<0) x = 0;
     if (y<0) y = 0;
     Scroll( x, y);
+#ifdef __WXMSW__
+    // repaint image, so that labels and magnifier are updated
+    // only needed on Windows, on wxGTK this is handled by the 
+    // underlying control
+    update();
+#endif
 }
 
 const wxSize CPImageCtrl::GetBitmapSize() const
@@ -1759,6 +1811,16 @@ HuginBase::ImageCache::ImageCacheRGB8Ptr CPImageCtrl::GetImg()
     return m_img->get8BitImage();
 };
 
+void CPImageCtrl::ShowLines(bool isShown)
+{
+    m_showLines = isShown;
+}
+
+bool CPImageCtrl::IsShowingLines() const
+{
+    return m_showLines;
+}
+
 IMPLEMENT_DYNAMIC_CLASS(CPImageCtrl, wxScrolledWindow)
 
 CPImageCtrlXmlHandler::CPImageCtrlXmlHandler()
