@@ -88,6 +88,7 @@ class GLwxAuiFloatingFrame;
 #include <wx/aui/aui.h>
 #include <wx/clrpicker.h>
 #include "hugin/GuiLevel.h"
+#include "hugin/SplitButton.h"
 
 #include <iostream>
 
@@ -216,6 +217,10 @@ public:
     void InitPreviews();
     /** sets the gui level */
     void SetGuiLevel(GuiLevel newLevel);
+    /** adds the given user defined output sequence to SplitButton menu */
+    void AddUserDefinedSequence(int id, const wxString& desc, const wxString& help);
+    /** adds the given user defined assistant to SplitButton menu */
+    void AddUserDefinedAssistant(int id, const wxString& desc, const wxString& help);
 
     GLwxAuiManager* getAuiManager() {return m_mgr;}
     GLPreview* getPreview() {return m_GLPreview;}
@@ -332,20 +337,15 @@ protected:
     void OnShowMainFrame(wxCommandEvent &e);
     // assistant related event handler
     void OnLoadImages( wxCommandEvent & e );
+    void LoadImages(int preferredLensType);
     void OnAlign( wxCommandEvent & e );
     void OnCreate( wxCommandEvent & e );
-    void OnLensTypeChanged (wxCommandEvent & e);
-    void OnFocalLengthChanged(wxCommandEvent & e);
-    void OnCropFactorChanged(wxCommandEvent & e);
-
     /** handler for creating cp in pano space */
     void OnCreateCP(wxCommandEvent & e);
     /** handler to remove cp */
     void OnRemoveCP(wxCommandEvent & e);
     /** handle menu close event */
     void OnMenuClose(wxMenuEvent & e);
-    /** handle context menu on select all button */
-    void OnSelectContextMenu(wxContextMenuEvent& e);
     /** handle all options of select all context menu */
     void OnSelectAllMenu(wxCommandEvent& e);
     void OnSelectMedianMenu(wxCommandEvent& e);
@@ -410,17 +410,12 @@ private:
     /// Bar for context sensitive projection information.
     wxInfoBar * m_infoBar;
     //assistant related controls
-    wxStaticText * m_imagesText;
-    wxButton * m_alignButton;
-    wxButton * m_createButton;
-    wxChoice   * m_lensTypeChoice;
-    wxTextCtrl * m_focalLengthText;
-    wxTextCtrl * m_cropFactorText;
-    wxButton   * m_loadLensButton;
+    SplitButton * m_loadImagesButton;
+    SplitButton * m_alignButton;
+    SplitButton * m_createButton;
     wxMenu* m_filemenuSimple;
     wxMenu* m_filemenuAdvanced;
-    wxMenu* m_selectAllMenu;
-    wxButton* m_selectAllButton;
+    SplitButton* m_selectAllButton;
     enum SelectAllMode
     {
         SELECT_ALL_IMAGES = 0,
