@@ -247,10 +247,12 @@ void GLOverview::setUp()
                                  plane_m_visualization_state, plane_m_tool_helper, m_background_color);
                                  
     switch(mode) {
-        case PANOSPHERE:
+        case PANOSPHERE_OUTSIDE:
+        case PANOSPHERE_INSIDE:
             m_visualization_state = panosphere_m_visualization_state;
             m_tool_helper = panosphere_m_tool_helper;
             m_renderer = panosphere_m_renderer;
+            panosphere_m_visualization_state->setInsideView(mode == PANOSPHERE_INSIDE);
             break;
         case PLANE:
             m_visualization_state = plane_m_visualization_state;
@@ -469,10 +471,12 @@ void GLOverview::SetMode(OverviewMode mode)
     this->mode = mode;
     if (panosphere_m_renderer != 0 && plane_m_renderer != 0) {
         switch(mode) {
-            case PANOSPHERE:
+            case PANOSPHERE_OUTSIDE:
+            case PANOSPHERE_INSIDE:
                 m_visualization_state = panosphere_m_visualization_state;
                 m_tool_helper = panosphere_m_tool_helper;
                 m_renderer = panosphere_m_renderer;
+                panosphere_m_visualization_state->setInsideView(mode == PANOSPHERE_INSIDE);
                 break;
             case PLANE:
                 m_visualization_state = plane_m_visualization_state;
