@@ -466,119 +466,6 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
     GetMenuBar()->Enable(XRCID("action_python_script"), false);
 #endif
 
-    // add saved user defined output sequences
-    {
-        wxArrayString files;
-        // search all .executor files, do not follow links
-        wxDir::GetAllFiles(GetDataPath(), &files, wxT("*.executor"), wxDIR_FILES | wxDIR_HIDDEN | wxDIR_NO_FOLLOW);
-        const size_t nrAllUserSequences = files.size();
-        wxDir::GetAllFiles(hugin_utils::GetUserAppDataDir(), &files, wxT("*.executor"), wxDIR_FILES | wxDIR_HIDDEN | wxDIR_NO_FOLLOW);
-        if (!files.IsEmpty())
-        {
-            // we found some files
-            long outputId = wxIDUSEROUTPUTSEQUENCE;
-            int outputMenuId=mainMenu->FindMenu(_("&Output"));
-            if (outputMenuId != wxNOT_FOUND)
-            {
-                wxMenu* outputSequencesMenu = new wxMenu;
-                size_t i = 0;
-                for (auto file : files)
-                {
-                    if (i > 0 && i == nrAllUserSequences && outputSequencesMenu->GetMenuItemCount() > 0)
-                    {
-                        outputSequencesMenu->AppendSeparator();
-                    };
-                    wxFileInputStream inputStream(file);
-                    if (inputStream.IsOk())
-                    {
-                        // read descriptions from file
-                        wxFileConfig executorFile(inputStream);
-                        wxString desc = HuginQueue::GetSettingStringTranslated(&executorFile, wxT("/General/Description"), wxEmptyString);
-                        wxString help = HuginQueue::GetSettingStringTranslated(&executorFile, wxT("/General/Help"), wxEmptyString);
-                        if (help.IsEmpty())
-                        {
-                            help = wxString::Format(_("User defined sequence: %s"), file);
-                        };
-                        // add menu
-                        if (!desc.IsEmpty())
-                        {
-                            outputSequencesMenu->Append(outputId, desc, help);
-                            Bind(wxEVT_MENU, &MainFrame::OnUserDefinedStitchSaved, this, outputId);
-                            m_userOutput[outputId] = file;
-                            ++outputId;
-                        };
-                    };
-                    i++;
-                };
-                if ((outputSequencesMenu->GetMenuItemCount() == 1 && !(outputSequencesMenu->FindItemByPosition(0)->IsSeparator())) ||
-                    outputSequencesMenu->GetMenuItemCount() > 1)
-                {
-                    m_outputUserMenu = mainMenu->GetMenu(outputMenuId)->AppendSubMenu(outputSequencesMenu, _("User defined output sequences"));
-                }
-                else
-                {
-                    delete outputSequencesMenu;
-                };
-            };
-        };
-    };
-    // add saved user defined assistants
-    {
-        wxArrayString files;
-        // search all .assistant files, do not follow links
-        wxDir::GetAllFiles(GetDataPath(), &files, wxT("*.assistant"), wxDIR_FILES | wxDIR_HIDDEN | wxDIR_NO_FOLLOW);
-        const size_t nrAllUserSequences = files.size();
-        wxDir::GetAllFiles(hugin_utils::GetUserAppDataDir(), &files, wxT("*.assistant"), wxDIR_FILES | wxDIR_HIDDEN | wxDIR_NO_FOLLOW);
-        if (!files.IsEmpty())
-        {
-            // we found some files
-            long assistantId = wxIDUSERASSISTANT;
-            const int editMenuId = mainMenu->FindMenu(_("&Edit"));
-            if (editMenuId != wxNOT_FOUND)
-            {
-                wxMenu* userAssistantMenu = new wxMenu;
-                size_t i = 0;
-                for (auto file : files)
-                {
-                    if (i > 0 && i == nrAllUserSequences && userAssistantMenu->GetMenuItemCount() > 0)
-                    {
-                        userAssistantMenu->AppendSeparator();
-                    };
-                    wxFileInputStream inputStream(file);
-                    if (inputStream.IsOk())
-                    {
-                        // read descriptions from file
-                        wxFileConfig assistantFile(inputStream);
-                        wxString desc = HuginQueue::GetSettingStringTranslated(&assistantFile, wxT("/General/Description"), wxEmptyString);
-                        wxString help = HuginQueue::GetSettingStringTranslated(&assistantFile, wxT("/General/Help"), wxEmptyString);
-                        help = help.Trim(true).Trim(false);
-                        if (help.IsEmpty())
-                        {
-                            help = wxString::Format(_("User defined assistant: %s"), file);
-                        };
-                        // add menu
-                        if (!desc.IsEmpty())
-                        {
-                            userAssistantMenu->Append(assistantId, desc, help);
-                            Bind(wxEVT_MENU, &MainFrame::OnRunAssistantUserdefined, this, assistantId);
-                            m_userAssistant[assistantId] = file;
-                            ++assistantId;
-                        };
-                    };
-                    i++;
-                };
-                if (userAssistantMenu->GetMenuItemCount() > 0)
-                {
-                    m_assistantUserMenu = mainMenu->GetMenu(editMenuId)->Insert(5, wxID_ANY, _("User defined assistant"), userAssistantMenu);
-                }
-                else
-                {
-                    delete userAssistantMenu;
-                };
-            };
-        };
-    };
-
     // create tool bar
     SetToolBar(wxXmlResource::Get()->LoadToolBar(this, wxT("main_toolbar")));
 
@@ -645,6 +532,141 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
         gl_preview_frame = new GLPreviewFrame(this, pano);
     };
 
+    // add saved user defined output sequences
+    {
+        wxArrayString files;
+        // search all .executor files, do not follow links
+        wxDir::GetAllFiles(GetDataPath()+"output", &files, wxT("*.executor"), wxDIR_FILES | wxDIR_HIDDEN | wxDIR_NO_FOLLOW);
+        const size_t nrAllUserSequences = files.size();
+        wxDir::GetAllFiles(hugin_utils::GetUserAppDataDir(), &files, wxT("*.executor"), wxDIR_FILES | wxDIR_HIDDEN | wxDIR_NO_FOLLOW);
+        if (!files.IsEmpty())
+        {
+            // we found some files
+            long outputId = wxIDUSEROUTPUTSEQUENCE;
+            int outputMenuId=mainMenu->FindMenu(_("&Output"));
+            if (outputMenuId != wxNOT_FOUND)
+            {
+                wxMenu* outputSequencesMenu = new wxMenu;
+                size_t i = 0;
+                for (auto file : files)
+                {
+                    if (i > 0 && i == nrAllUserSequences && outputSequencesMenu->GetMenuItemCount() > 0)
+                    {
+                        outputSequencesMenu->AppendSeparator();
+                        if (gl_preview_frame)
+                        {
+                            // add assistant to context menu on align button
+                            gl_preview_frame->AddUserDefinedSequence(-1, wxEmptyString, wxEmptyString);
+                        };
+
+                    };
+                    wxFileInputStream inputStream(file);
+                    if (inputStream.IsOk())
+                    {
+                        // read descriptions from file
+                        wxFileConfig executorFile(inputStream);
+                        wxString desc = HuginQueue::GetSettingStringTranslated(&executorFile, wxT("/General/Description"), wxEmptyString);
+                        wxString help = HuginQueue::GetSettingStringTranslated(&executorFile, wxT("/General/Help"), wxEmptyString);
+                        if (help.IsEmpty())
+                        {
+                            help = wxString::Format(_("User defined sequence: %s"), file);
+                        };
+                        // add menu
+                        if (!desc.IsEmpty())
+                        {
+                            outputSequencesMenu->Append(outputId, desc, help);
+                            Bind(wxEVT_MENU, &MainFrame::OnUserDefinedStitchSaved, this, outputId);
+                            m_userOutput[outputId] = file;
+                            if (gl_preview_frame)
+                            {
+                                // add output sequence to context menu on create button
+                                gl_preview_frame->AddUserDefinedSequence(outputId, desc, help);
+                            };
+                            ++outputId;
+                        };
+                    };
+                    i++;
+                };
+                if ((outputSequencesMenu->GetMenuItemCount() == 1 && !(outputSequencesMenu->FindItemByPosition(0)->IsSeparator())) ||
+                    outputSequencesMenu->GetMenuItemCount() > 1)
+                {
+                    m_outputUserMenu = mainMenu->GetMenu(outputMenuId)->AppendSubMenu(outputSequencesMenu, _("User defined output sequences"));
+                }
+                else
+                {
+                    delete outputSequencesMenu;
+                };
+            };
+        };
+    };
+    // add saved user defined assistants
+    {
+        wxArrayString files;
+        // search all .assistant files, do not follow links
+        wxDir::GetAllFiles(GetDataPath() + "assistant", &files, wxT("*.assistant"), wxDIR_FILES | wxDIR_HIDDEN | wxDIR_NO_FOLLOW);
+        const size_t nrAllUserSequences = files.size();
+        wxDir::GetAllFiles(hugin_utils::GetUserAppDataDir(), &files, wxT("*.assistant"), wxDIR_FILES | wxDIR_HIDDEN | wxDIR_NO_FOLLOW);
+        if (!files.IsEmpty())
+        {
+            // we found some files
+            long assistantId = wxIDUSERASSISTANT;
+            const int editMenuId = mainMenu->FindMenu(_("&Edit"));
+            if (editMenuId != wxNOT_FOUND)
+            {
+                wxMenu* userAssistantMenu = new wxMenu;
+                size_t i = 0;
+                for (auto file : files)
+                {
+                    if (i > 0 && i == nrAllUserSequences && userAssistantMenu->GetMenuItemCount() > 0)
+                    {
+                        userAssistantMenu->AppendSeparator();
+                        if (gl_preview_frame)
+                        {
+                            // add assistant to context menu on align button
+                            gl_preview_frame->AddUserDefinedAssistant(-1, wxEmptyString, wxEmptyString);
+                        };
+                    };
+                    wxFileInputStream inputStream(file);
+                    if (inputStream.IsOk())
+                    {
+                        // read descriptions from file
+                        wxFileConfig assistantFile(inputStream);
+                        wxString desc = HuginQueue::GetSettingStringTranslated(&assistantFile, wxT("/General/Description"), wxEmptyString);
+                        wxString help = HuginQueue::GetSettingStringTranslated(&assistantFile, wxT("/General/Help"), wxEmptyString);
+                        help = help.Trim(true).Trim(false);
+                        if (help.IsEmpty())
+                        {
+                            help = wxString::Format(_("User defined assistant: %s"), file);
+                        };
+                        // add menu
+                        if (!desc.IsEmpty())
+                        {
+                            userAssistantMenu->Append(assistantId, desc, help);
+                            Bind(wxEVT_MENU, &MainFrame::OnRunAssistantUserdefined, this, assistantId);
+                            m_userAssistant[assistantId] = file;
+                            if (gl_preview_frame)
+                            {
+                                // add assistant to context menu on align button
+                                gl_preview_frame->AddUserDefinedAssistant(assistantId, desc, help);
+                            };
+                            ++assistantId;
+                        };
+                    };
+                    i++;
+                };
+                if (userAssistantMenu->GetMenuItemCount() > 0)
+                {
+                    m_assistantUserMenu = mainMenu->GetMenu(editMenuId)->Insert(5, wxID_ANY, _("User defined assistant"), userAssistantMenu);
+                }
+                else
+                {
+                    delete userAssistantMenu;
+                };
+            };
+        };
+    };
+
+
     // set the minimize icon
 #ifdef __WXMSW__
     wxIconBundle myIcons(GetXRCPath() + wxT("data/hugin.ico"), wxBITMAP_TYPE_ICO);
