@@ -36,14 +36,12 @@
 #include "hugin/MaskImageCtrl.h"
 #include "hugin/MaskEditorPanel.h"
 #include "base_wx/wxImageCache.h"
-#ifndef SUPPORTS_WXINVERT
 #include <vigra/inspectimage.hxx>
-#endif
 
 /** half size of markers */
 const int polygonPointSize=3;
 /** maximal distance for selection of one point */
-const int maxSelectionDistance=20;
+const int maxSelectionDistance = 10;
 
 // our image control
 
@@ -55,7 +53,10 @@ BEGIN_EVENT_TABLE(MaskImageCtrl, wxScrolledWindow)
     EVT_LEFT_DCLICK(MaskImageCtrl::OnLeftMouseDblClick)
     EVT_RIGHT_DOWN(MaskImageCtrl::OnRightMouseDown)
     EVT_RIGHT_UP(MaskImageCtrl::OnRightMouseUp)
+    EVT_MIDDLE_DOWN(MaskImageCtrl::OnMiddleMouseDown)
+    EVT_MIDDLE_UP(MaskImageCtrl::OnMiddleMouseUp)
     EVT_KEY_UP(MaskImageCtrl::OnKeyUp)
+    EVT_CHAR(MaskImageCtrl::OnChar)
     EVT_MOUSE_CAPTURE_LOST(MaskImageCtrl::OnCaptureLost)
     EVT_KILL_FOCUS(MaskImageCtrl::OnKillFocus)
     EVT_SCROLLWIN(MaskImageCtrl::OnScroll)
@@ -78,6 +79,7 @@ bool MaskImageCtrl::Create(wxWindow * parent, wxWindowID id,
     m_maskMode = true;
     m_oldScrollPosX = -1;
     m_oldScrollPosY = -1;
+    m_middleMouseScroll = false;
 
     return true;
 }
@@ -403,6 +405,15 @@ void MaskImageCtrl::OnMouseMove(wxMouseEvent& mouse)
 {
     if(m_previewOnly)
         return;
+    if (m_middleMouseScroll)
+    {
+        // handle scrolling and break out
+        wxPoint viewStart = GetViewStart();
+        viewStart = viewStart - (mouse.GetPosition() - m_scrollPos);
+        Scroll(viewStart);
+        m_scrollPos = mouse.GetPosition();
+        return;
+    };
     wxPoint mpos;
     CalcUnscrolledPosition(mouse.GetPosition().x, mouse.GetPosition().y,
                            &mpos.x, & mpos.y);
@@ -417,9 +428,6 @@ void MaskImageCtrl::OnMouseMove(wxMouseEvent& mouse)
         case POLYGON_SELECTING:
         case REGION_SELECTING:
         case POINTS_DELETING:
-#if defined SUPPORTS_WXINVERT
-            DrawSelectionRectangle();
-#endif
             m_currentPos=mpos;
             DrawSelectionRectangle();
             break;
@@ -487,16 +495,9 @@ void MaskImageCtrl::OnMouseMove(wxMouseEvent& mouse)
         case CROP_TOP_MOVING:
         case CROP_BOTTOM_MOVING:
         case CROP_CIRCLE_SCALING:
-#if defined SUPPORTS_WXINVERT
-            DrawCrop();
-#else
-            doUpdate=true;
-#endif
             UpdateCrop(currentPos);
             m_currentPos=mpos;
-#if defined SUPPORTS_WXINVERT
             DrawCrop();
-#endif
             m_editPanel->UpdateCropFromImage();
             break;
         case NO_IMAGE:
@@ -534,14 +535,13 @@ void MaskImageCtrl::OnLeftMouseDown(wxMouseEvent& mouse)
             if(m_maskMode)
             {
                 m_maskEditState=POLYGON_SELECTING;
-                DrawSelectionRectangle();
             };
             break;
         case NO_SELECTION:
             if(mouse.CmdDown())
             {
                 // check if mouse clicks happens near one line of active polygon
-                unsigned int index=m_editingMask.FindPointNearPos(currentPos,5*maxSelectionDistance);
+                unsigned int index = m_editingMask.FindPointNearPos(currentPos, 5 * maxSelectionDistance / getScaleFactor());
                 if(index<UINT_MAX)
                 {
                     m_selectedPoints.clear();
@@ -562,7 +562,6 @@ void MaskImageCtrl::OnLeftMouseDown(wxMouseEvent& mouse)
                 else
                 {
                     m_maskEditState=REGION_SELECTING;
-                    DrawSelectionRectangle();
                 }
             };
             break;
@@ -570,7 +569,7 @@ void MaskImageCtrl::OnLeftMouseDown(wxMouseEvent& mouse)
             if(mouse.CmdDown())
             {
                 // check if mouse clicks happens near one line of active polygon
-                unsigned int index=m_editingMask.FindPointNearPos(currentPos, 5*maxSelectionDistance);
+                unsigned int index = m_editingMask.FindPointNearPos(currentPos, 5 * maxSelectionDistance / getScaleFactor());
                 if(index<UINT_MAX)
                 {
                     m_selectedPoints.clear();
@@ -602,7 +601,6 @@ void MaskImageCtrl::OnLeftMouseDown(wxMouseEvent& mouse)
                     else
                     {
                         m_maskEditState=REGION_SELECTING;
-                        DrawSelectionRectangle();
                     };
                 }
             };
@@ -637,20 +635,11 @@ void MaskImageCtrl::OnLeftMouseDown(wxMouseEvent& mouse)
                     m_maskEditState=CROP_CIRCLE_SCALING;
                     break;
             };
-            if(m_maskEditState!=CROP_SHOWING)
+            if (m_cropMode == HuginBase::SrcPanoImage::NO_CROP && m_cropCircle)
             {
-                if (m_cropMode == HuginBase::SrcPanoImage::NO_CROP && m_cropCircle)
-                {
-#if defined SUPPORTS_WXINVERT
-                    DrawCrop();
-                    m_cropMode = HuginBase::SrcPanoImage::CROP_CIRCLE;
-                    DrawCrop();
-#else
-                    m_cropMode=HuginBase::SrcPanoImage::CROP_CIRCLE;
-                    update();
-#endif
-                };
+                m_cropMode = HuginBase::SrcPanoImage::CROP_CIRCLE;
             };
+            ClearOverlay();
             break;
         default:
             // otherwise do nothing
@@ -660,7 +649,7 @@ void MaskImageCtrl::OnLeftMouseDown(wxMouseEvent& mouse)
 
 void MaskImageCtrl::OnLeftMouseUp(wxMouseEvent& mouse)
 {
-    if(m_previewOnly)
+    if(m_previewOnly || m_middleMouseScroll)
         return;
     DEBUG_DEBUG("LEFT MOUSE UP");
     wxPoint mpos;
@@ -687,7 +676,7 @@ void MaskImageCtrl::OnLeftMouseUp(wxMouseEvent& mouse)
                 ReleaseMouse();
             {
                 hugin_utils::FDiff2D delta=currentPos-applyRotInv(invtransform(m_dragStartPos));
-                if(hugin_utils::sqr(delta.x)+hugin_utils::sqr(delta.y)>hugin_utils::sqr(maxSelectionDistance))
+                if (hugin_utils::sqr(delta.x) + hugin_utils::sqr(delta.y) > hugin_utils::sqr(maxSelectionDistance / getScaleFactor() / 2.0))
                 {
                     for(HuginBase::UIntSet::const_iterator it=m_selectedPoints.begin();it!=m_selectedPoints.end();++it)
                         m_imageMask[m_activeMask].movePointBy(*it,delta);
@@ -705,11 +694,7 @@ void MaskImageCtrl::OnLeftMouseUp(wxMouseEvent& mouse)
         case POLYGON_SELECTING:
             if(HasCapture())
                 ReleaseMouse();
-#if defined SUPPORTS_WXINVERT
-            DrawSelectionRectangle();
-#else
-            doUpdate=true;
-#endif
+            ClearOverlay();
             m_currentPos=mpos;
             m_maskEditState=NO_SELECTION;
             {
@@ -724,7 +709,7 @@ void MaskImageCtrl::OnLeftMouseUp(wxMouseEvent& mouse)
             {
                 if(HasCapture())
                     ReleaseMouse();
-                DrawSelectionRectangle();
+                ClearOverlay();
                 m_currentPos=mpos;
                 bool selectedPoints=!m_selectedPoints.empty();
                 if(!mouse.ShiftDown())
@@ -771,15 +756,8 @@ void MaskImageCtrl::OnLeftMouseUp(wxMouseEvent& mouse)
         case CROP_CIRCLE_SCALING:
             if(HasCapture())
                 ReleaseMouse();
-#if defined SUPPORTS_WXINVERT
-            DrawCrop();
-#else
-            doUpdate=true;
-#endif
+            ClearOverlay();
             UpdateCrop(currentPos);
-#if defined SUPPORTS_WXINVERT
-            DrawCrop();
-#endif
             m_maskEditState=CROP_SHOWING;
             SetCursor(wxNullCursor);
             m_editPanel->UpdateCrop(true);
@@ -794,7 +772,7 @@ void MaskImageCtrl::OnLeftMouseUp(wxMouseEvent& mouse)
 
 void MaskImageCtrl::OnLeftMouseDblClick(wxMouseEvent &mouse)
 {
-    if(m_previewOnly)
+    if(m_previewOnly || m_middleMouseScroll)
         return;
     switch(m_maskEditState)
     {
@@ -838,7 +816,7 @@ void MaskImageCtrl::OnLeftMouseDblClick(wxMouseEvent &mouse)
 
 void MaskImageCtrl::OnRightMouseDown(wxMouseEvent& mouse)
 {
-    if(m_previewOnly)
+    if(m_previewOnly || m_middleMouseScroll)
         return;
     CalcUnscrolledPosition(mouse.GetPosition().x, mouse.GetPosition().y,
                            &m_dragStartPos.x, & m_dragStartPos.y);
@@ -852,7 +830,6 @@ void MaskImageCtrl::OnRightMouseDown(wxMouseEvent& mouse)
         if(mouse.CmdDown())
         {
             m_maskEditState=POINTS_DELETING;
-            DrawSelectionRectangle();
         }
         else
         {
@@ -868,7 +845,7 @@ void MaskImageCtrl::OnRightMouseDown(wxMouseEvent& mouse)
 
 void MaskImageCtrl::OnRightMouseUp(wxMouseEvent& mouse)
 {
-    if(m_previewOnly)
+    if(m_previewOnly || m_middleMouseScroll)
         return;
     wxPoint mpos;
     CalcUnscrolledPosition(mouse.GetPosition().x, mouse.GetPosition().y,
@@ -910,7 +887,6 @@ void MaskImageCtrl::OnRightMouseUp(wxMouseEvent& mouse)
             };
         case POINTS_DELETING:
             {
-                DrawSelectionRectangle();
                 HuginBase::UIntSet points;
                 m_currentPos=mpos;
                 if(SelectPointsInsideMouseRect(points,false))
@@ -954,7 +930,7 @@ void MaskImageCtrl::OnRightMouseUp(wxMouseEvent& mouse)
         case POINTS_MOVING:
             {
                 hugin_utils::FDiff2D delta=currentPos-applyRotInv(invtransform(m_dragStartPos));
-                if(hugin_utils::sqr(delta.x)+hugin_utils::sqr(delta.y)>hugin_utils::sqr(maxSelectionDistance))
+                if (hugin_utils::sqr(delta.x) + hugin_utils::sqr(delta.y) > hugin_utils::sqr(maxSelectionDistance / getScaleFactor() / 2.0))
                 {
                     for(HuginBase::UIntSet::const_iterator it=m_selectedPoints.begin();it!=m_selectedPoints.end();++it)
                         m_imageMask[m_activeMask].movePointBy(*it,delta);
@@ -973,6 +949,48 @@ void MaskImageCtrl::OnRightMouseUp(wxMouseEvent& mouse)
     };
 };
 
+void MaskImageCtrl::OnMiddleMouseDown(wxMouseEvent& mouse)
+{
+    if (m_previewOnly || m_middleMouseScroll)
+    {
+        return;
+    };
+    switch (m_maskEditState)
+    {
+        case NO_MASK:
+        case NO_SELECTION:
+        case POINTS_SELECTED:
+        case POINTS_ADDING:
+        case NEW_POLYGON_STARTED:
+        case NEW_POLYGON_CREATING:
+        case CROP_SHOWING:
+            if (!HasCapture())
+                CaptureMouse();
+            // store the scroll rate, the scroll rate set in rescaleImage is optimized for srolling
+            // with the cursor keys, but this is too high for mouse scrolling
+            // so change the scroll rate here and restore later in OnMiddleMouseUp
+            m_middleMouseScroll = true;
+            m_scrollPos = mouse.GetPosition();
+            break;
+        default:
+            // in other case ignore the middle mouse button
+            break;
+    };
+}
+
+void MaskImageCtrl::OnMiddleMouseUp(wxMouseEvent& mouse)
+{
+    if (m_previewOnly)
+    {
+        return;
+    };
+    if (HasCapture())
+    {
+        ReleaseMouse();
+    };
+    m_middleMouseScroll = false;
+}
+
 void MaskImageCtrl::OnKeyUp(wxKeyEvent &e)
 {
     const int key=e.GetKeyCode();
@@ -1053,6 +1071,37 @@ void MaskImageCtrl::OnKeyUp(wxKeyEvent &e)
         e.Skip();
 };
 
+void MaskImageCtrl::OnChar(wxKeyEvent& e)
+{
+    wxPoint offset = GetViewStart();
+    const int speed = std::max(m_bitmap.GetWidth(), m_bitmap.GetHeight()) / 75;
+    switch (e.GetKeyCode())
+    {
+        // the default scrolling behaviour of the cursor key is too fine
+        // using SetScrollRate with higher values conflicts with the middle mouse button
+        // scrollling
+        // so instead handle the cursor scrolling here with a higher step rate
+        case WXK_LEFT:
+            offset.x -= speed;
+            Scroll(offset);
+            break;
+        case WXK_RIGHT:
+            offset.x += speed;
+            Scroll(offset);
+            break;
+        case WXK_UP:
+            offset.y -= speed;
+            Scroll(offset);
+            break;
+        case WXK_DOWN:
+            offset.y += speed;
+            Scroll(offset);
+            break;
+        default:
+            //process event further
+            e.Skip();
+    };
+}
 void MaskImageCtrl::OnCaptureLost(wxMouseCaptureLostEvent &e)
 {
     wxFocusEvent dummy;
@@ -1161,13 +1210,11 @@ void MaskImageCtrl::DrawCrop(wxDC & dc)
     // draw crop rectangle/circle
     if(!m_maskMode)
     {
+        wxDCOverlay overlayDC(m_overlay, &dc);
+        overlayDC.Clear();
         // draw all areas without fillings
         dc.SetBrush(*wxTRANSPARENT_BRUSH);
-#if defined SUPPORTS_WXINVERT
-        dc.SetLogicalFunction (wxINVERT);
-#else
-        dc.SetPen(wxPen(m_color_selection, 1, wxPENSTYLE_SOLID));
-#endif
+        dc.SetPen(wxPen(m_color_selection, 2, wxPENSTYLE_SOLID));
         wxPoint middle=transform(applyRot((m_cropRect.lowerRight()+m_cropRect.upperLeft())/2));
 
         int c = 8; // size of midpoint cross
@@ -1313,6 +1360,15 @@ void MaskImageCtrl::OnDraw(wxDC & dc)
     };
 }
 
+void MaskImageCtrl::ClearOverlay()
+{
+    wxClientDC dc(this);
+    PrepareDC(dc);
+    wxDCOverlay overlaydc(m_overlay, &dc);
+    overlaydc.Clear();
+    m_overlay.Reset();
+}
+
 void MaskImageCtrl::OnSize(wxSizeEvent &e)
 {
     DEBUG_TRACE("size: " << e.GetSize().GetWidth() << "x" << e.GetSize().GetHeight());
@@ -1337,7 +1393,6 @@ void MaskImageCtrl::rescaleImage()
     {
         return;
     }
-#ifndef SUPPORTS_WXINVERT
     //determine average colour and set selection colour corresponding
     vigra::FindAverage<vigra::RGBValue<vigra::UInt8> > average;
     vigra::inspectImage(vigra::srcImageRange(*(m_img->get8BitImage())), average);
@@ -1350,7 +1405,6 @@ void MaskImageCtrl::rescaleImage()
     {
         m_color_selection=*wxBLACK;
     };
-#endif
     wxImage img = imageCacheEntry2wxImage(m_img);
     if (img.GetWidth() == 0)
     {
@@ -1391,9 +1445,7 @@ void MaskImageCtrl::rescaleImage()
             img = img.Rotate90(true);
             break;
         case ROT180:
-                // this is slower than it needs to be...
-            img = img.Rotate90(true);
-            img = img.Rotate90(true);
+            img = img.Rotate180();
             break;
         case ROT270:
             img = img.Rotate90(false);
@@ -1419,7 +1471,7 @@ void MaskImageCtrl::rescaleImage()
     {
         SetVirtualSize(m_imageSize.GetWidth(), m_imageSize.GetHeight());
     };
-    SetScrollRate(std::max<int>(1, m_bitmap.GetWidth() / 75), std::max<int>(1, m_bitmap.GetHeight() / 75));
+    SetScrollRate(1, 1);
     Refresh(true);
 };
 
@@ -1427,13 +1479,9 @@ void MaskImageCtrl::DrawSelectionRectangle()
 {
     wxClientDC dc(this);
     PrepareDC(dc);
-#if defined SUPPORTS_WXINVERT
-    dc.SetLogicalFunction(wxINVERT);
-    dc.SetPen(wxPen(*wxWHITE, 1, wxPENSTYLE_DOT));
-#else
-    OnDraw(dc);
-    dc.SetPen(wxPen(m_color_selection, scale(1), wxPENSTYLE_DOT));
-#endif
+    wxDCOverlay overlayDC(m_overlay, &dc);
+    overlayDC.Clear();
+    dc.SetPen(wxPen(m_color_selection, 2, wxPENSTYLE_LONG_DASH));
     dc.SetBrush(*wxTRANSPARENT_BRUSH);
     dc.DrawRectangle(m_dragStartPos.x,m_dragStartPos.y,
         (m_currentPos.x-m_dragStartPos.x),(m_currentPos.y-m_dragStartPos.y));
@@ -1458,10 +1506,10 @@ bool MaskImageCtrl::SelectPointsInsideMouseRect(HuginBase::UIntSet &points,const
     bool found=false;
     hugin_utils::FDiff2D p1=applyRotInv(invtransform(m_dragStartPos));
     hugin_utils::FDiff2D p2=applyRotInv(invtransform(m_currentPos));
-    double xmin=std::min(p1.x,p2.x)-maxSelectionDistance;
-    double xmax=std::max(p1.x,p2.x)+maxSelectionDistance;
-    double ymin=std::min(p1.y,p2.y)-maxSelectionDistance;
-    double ymax=std::max(p1.y,p2.y)+maxSelectionDistance;
+    double xmin = std::min(p1.x, p2.x) - maxSelectionDistance / getScaleFactor();
+    double xmax = std::max(p1.x, p2.x) + maxSelectionDistance / getScaleFactor();
+    double ymin = std::min(p1.y, p2.y) - maxSelectionDistance / getScaleFactor();
+    double ymax = std::max(p1.y, p2.y) + maxSelectionDistance / getScaleFactor();
     const HuginBase::VectorPolygon poly=m_editingMask.getMaskPolygon();
     for(unsigned int i=0;i<poly.size();i++)
     {
@@ -1496,6 +1544,7 @@ void MaskImageCtrl::setScale(double factor)
         // keep existing scale focussed.
         rescaleImage();
     }
+    m_overlay.Reset();
 };
 
 double MaskImageCtrl::calcAutoScaleFactor(wxSize size)
