@@ -27,22 +27,7 @@
 #define _MaskImageCtrl_H
 
 #include <base_wx/wxImageCache.h>
-
-#if defined __WXOSX_CARBON__ || defined __WXOSX_COCOA__
-// on wxMac wxInvert does not work for drawing rubberband, so we are the following workaround
-// instead of using wxInvert we are drawing the background image before the selection rectangle
-// or the crop rectangle, the color of the selection is defined by the overall colour of the image
-// this approach is already used for the polygon editor also on wxMSW and wxGTK
-#undef SUPPORTS_WXINVERT
-#else
-#ifdef __WXGTK3__
-// wxINVERT is currently also not supported on GTK+3
-// see ticket http://trac.wxwidgets.org/ticket/16890
-#undef SUPPORTS_WXINVERT
-#else
-#define SUPPORTS_WXINVERT 1
-#endif
-#endif
+#include <wx/overlay.h>
 
 class MaskEditorPanel;
 
@@ -56,7 +41,7 @@ public:
     /** ctor.
      */
     MaskImageCtrl()
-        : m_maskEditState(NO_IMAGE), m_scaleFactor(1), m_fitToWindow(false)
+        : m_maskEditState(NO_IMAGE), m_scaleFactor(1), m_fitToWindow(false), m_middleMouseScroll(false)
         { }
 
     bool Create(wxWindow* parent, wxWindowID id = wxID_ANY, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = wxTAB_TRAVERSAL, const wxString& name = wxT("panel"));
@@ -98,8 +83,14 @@ public:
     void OnRightMouseDown(wxMouseEvent& mouse);
     /** event handler when right mouse button is released */
     void OnRightMouseUp(wxMouseEvent& mouse);
+    /** event handler for middle mouse button, start scrolling */
+    void OnMiddleMouseDown(wxMouseEvent& mouse);
+    /** event handler for middle mouse button, end scrolling */
+    void OnMiddleMouseUp(wxMouseEvent& mouse);
     /** event handler for keyboard */
     void OnKeyUp(wxKeyEvent &e);
+    /** event handler for scrolling with keyboard */
+    void OnChar(wxKeyEvent& e);
     /** event handler, when mouse capture is lost, e.g. user click outside of window 
      *  cancels creating of new mask */
     void OnCaptureLost(wxMouseCaptureLostEvent &e);
@@ -273,6 +264,8 @@ protected:
     bool SelectPointsInsideMouseRect(HuginBase::UIntSet &points,const bool considerSelectedOnly);
     // updates the crop
     void UpdateCrop(hugin_utils::FDiff2D delta);
+    // clears the overlay
+    void ClearOverlay();
 
     // where the cursor is 
     enum ClickPos
@@ -324,15 +317,17 @@ protected:
     // positions of mouse drag
     wxPoint m_dragStartPos;
     wxPoint m_currentPos;
+    // variable for saving scrolling state
+    bool m_middleMouseScroll;
+    wxPoint m_scrollPos;
 
     // colours for different parts
     wxColor m_colour_polygon_negative;
     wxColor m_colour_polygon_positive;
     wxColor m_colour_point_selected;
     wxColor m_colour_point_unselected;
-#ifndef SUPPORTS_WXINVERT
     wxColour m_color_selection;
-#endif
+    wxOverlay m_overlay;
     int m_oldScrollPosX, m_oldScrollPosY;
 
     DECLARE_EVENT_TABLE();
