@@ -19,6 +19,9 @@
  *
  */
 
+#ifdef _WIN32
+#include "wx/msw/wrapwin.h"
+#endif
 #include <GL/glew.h>
 #ifdef __WXMAC__
 #include <OpenGL/gl.h>
@@ -427,7 +430,7 @@ void OverviewOutlinesTool::DrawRect(double left, double top, double right, doubl
                 stack.push_back(Rec(true, true, true, true));
             }
             
-            while(stack.size() > 0) {
+            while(!stack.empty()) {
 
                 Rec edge;
                 if (outline) {
