@@ -60,6 +60,7 @@ extern "C" {
 #include "algorithms/basic/CalculateOptimalROI.h"
 #include "algorithms/nona/FitPanorama.h"
 #include "lensdb/LensDB.h"
+#include "hugin_math/hugin_math.h"
 
 #define WX_BROKEN_SIZER_UNKNOWN
 
@@ -101,6 +102,9 @@ BEGIN_EVENT_TABLE(PanoPanel, wxPanel)
     EVT_CHOICE ( XRCID("pano_choice_blender"),PanoPanel::BlenderChanged )
     EVT_BUTTON ( XRCID("pano_button_blender_opts"),PanoPanel::OnBlenderOptions )
 
+    EVT_CHOICE ( XRCID("pano_choice_edgefill"), PanoPanel::OnEdgeFillChanged)
+    EVT_BUTTON ( XRCID("pano_button_fill_opts"), PanoPanel::OnEdgeFillOptions)
+
     EVT_CHOICE ( XRCID("pano_choice_file_format"),PanoPanel::FileFormatChanged )
     EVT_CHOICE ( XRCID("pano_choice_hdr_file_format"),PanoPanel::HDRFileFormatChanged )
 //    EVT_SPINCTRL ( XRCID("pano_output_normal_opts_jpeg_quality"),PanoPanel::OnJPEGQualitySpin )
@@ -218,6 +222,7 @@ bool PanoPanel::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos, cons
     m_BlenderChoice = XRCCTRL(*this, "pano_choice_blender", wxChoice);
     DEBUG_ASSERT(m_BlenderChoice);
     FillBlenderList(m_BlenderChoice);
+    m_edgeFillChoice = XRCCTRL(*this, "pano_choice_edgefill", wxChoice);
 
     m_StitchButton = XRCCTRL(*this, "pano_button_stitch", wxButton);
     DEBUG_ASSERT(m_StitchButton);
@@ -388,50 +393,32 @@ void PanoPanel::UpdateDisplay(const HuginBase::PanoramaOptions & opt, const bool
     {
         // format text for display of canvas dimension
         wxString label = wxString::Format(wxT("%d x %d"), opt.getROI().width(), opt.getROI().height());
-        if (opt.getROI().area() >= 20000000)
+        // using opt.getROI().area() can overflow, so use width and height explicit to prevent this
+        if ( (opt.getROI().width() / 1000.0) * opt.getROI().height() / 1000.0 >= 20.0)
         {
-            label.Append(wxString::Format(wxT("=%.0f MP"), opt.getROI().area() / 1000000.0));
+            label.Append(wxString::Format(wxT("=%.0f MP"), (opt.getROI().width() / 1000.0) * opt.getROI().height() / 1000.0));
         }
         else
         {
             label.Append(wxString::Format(wxT("=%.1f MP"), opt.getROI().area() / 1000000.0));
         };
-        if (opt.getROI().area() > 0)
+        if (opt.getROI().width() >0 && opt.getROI().height() > 0)
         {
-            float ratio = 1.0f*opt.getROI().width() / opt.getROI().height();
-            if (ratio > 1.0f)
+            const int commonDivisor = hugin_utils::gcd(opt.getROI().width(), opt.getROI().height());
+            if (commonDivisor > std::pow(10, hugin_utils::floori(log10f(std::max(opt.getROI().width(), opt.getROI().height()))) - 2))
             {
-                bool handled = false;
-                for (unsigned int i = 1; i < 10; ++i)
-                {
-                    if (fabs(i*ratio - hugin_utils::roundi(i*ratio)) < 1e-2)
-                    {
-                        label.Append(wxString::Format(wxT(", %d:%d"), hugin_utils::roundi(i*ratio), i));
-                        handled = true;
-                        break;
-                    }
-                };
-                if (!handled)
-                {
-                    label.Append(wxString::Format(wxT(", %.2f:1"), ratio));
-                };
+                label.Append(wxString::Format(wxT(", %d:%d"), opt.getROI().width() / commonDivisor, opt.getROI().height() / commonDivisor));
             }
             else
             {
-                ratio = 1.0f / ratio;
-                bool handled = false;
-                for (unsigned int i = 1; i < 10; ++i)
+                float ratio = 1.0f * opt.getROI().width() / opt.getROI().height();
+                if (ratio > 1.0f)
                 {
-                    if (fabs(i*ratio - hugin_utils::roundi(i*ratio)) < 1e-2)
-                    {
-                        label.Append(wxString::Format(wxT(", %d:%d"), i, hugin_utils::roundi(i*ratio)));
-                        handled = true;
-                        break;
-                    }
-                };
-                if (!handled)
+                    label.Append(wxString::Format(wxT(", %.2f:1"), ratio));
+                }
+                else
                 {
-                    label.Append(wxString::Format(wxT(", 1:%.2f"), ratio));
+                    label.Append(wxString::Format(wxT(", 1:%.2f"), 1.0f/ratio));
                 };
             };
         };
@@ -528,6 +515,8 @@ void PanoPanel::UpdateDisplay(const HuginBase::PanoramaOptions & opt, const bool
     XRCCTRL(*this, "pano_button_blender_opts", wxButton)->Show(m_guiLevel>GUI_SIMPLE);
     XRCCTRL(*this, "pano_text_blender", wxStaticText)->Enable(blenderEnabled);
     XRCCTRL(*this, "pano_text_blender", wxStaticText)->Show(m_guiLevel>GUI_SIMPLE);
+    m_edgeFillChoice->SetSelection(static_cast<int>(opt.edgeFillMode));
+    XRCCTRL(*this, "pano_button_fill_opts", wxButton)->Enable(m_edgeFillChoice->GetSelection() != 0);
 
     bool fusionEnabled = (opt.outputLDRExposureBlended || opt.outputLDRExposureLayersFused || opt.outputLDRStacks) && m_guiLevel>GUI_SIMPLE;
     m_FusionChoice->Enable(fusionEnabled);
@@ -936,6 +925,37 @@ void PanoPanel::OnBlenderOptions(wxCommandEvent & e)
     };
 }
 
+void PanoPanel::OnEdgeFillChanged(wxCommandEvent & e)
+{
+    HuginBase::PanoramaOptions opt = pano->getOptions();
+    HuginBase::PanoramaOptions::EdgeFillMode newMode = static_cast<HuginBase::PanoramaOptions::EdgeFillMode>(e.GetSelection());
+    {
+        if (opt.edgeFillMode != newMode)
+        {
+            opt.edgeFillMode = newMode;
+            PanoCommand::GlobalCmdHist::getInstance().addCommand(
+                new PanoCommand::SetPanoOptionsCmd(*pano, opt)
+            );
+        };
+    };
+}
+
+void PanoPanel::OnEdgeFillOptions(wxCommandEvent& e)
+{
+    HuginBase::PanoramaOptions opt = pano->getOptions();
+    wxDialog dlg;
+    wxXmlResource::Get()->LoadDialog(&dlg, this, wxT("filledge_options_dialog"));
+    wxCheckBox* keepUnfillVersion = XRCCTRL(dlg, "edgefill_save_input", wxCheckBox);
+    keepUnfillVersion->SetValue(opt.keepEdgeFillInput);
+    dlg.CentreOnParent();
+
+    if (dlg.ShowModal() == wxID_OK)
+    {
+        opt.keepEdgeFillInput = keepUnfillVersion->IsChecked();
+        PanoCommand::GlobalCmdHist::getInstance().addCommand(new PanoCommand::SetPanoOptionsCmd(*pano, opt));
+    };
+}
+
 void PanoPanel::FusionChanged(wxCommandEvent & e)
 {
     int fusion = m_FusionChoice->GetSelection();
@@ -1225,8 +1245,19 @@ void PanoPanel::DoSendToBatch()
         bool showDlg=wxConfigBase::Get()->Read(wxT("ShowSaveMessage"), 1l)==1;
         if(showDlg)
         {
+            // show information that project file needs to be saved first
+            // and user has to give the output prefix afterwards
             wxDialog dlg;
             wxXmlResource::Get()->LoadDialog(&dlg, this, wxT("stitch_message_dlg"));
+            if (!(MainFrame::Get()->getProjectName().IsEmpty()))
+            {
+                // project file was already saved with a name, adapt message text for this use case
+                XRCCTRL(dlg, "stitch_message_text", wxStaticText)->SetLabel(
+                    wxString::Format(_("The project %s will be automatically saved before it can be sent to the batch processor PTBatcherGUI.\nYou will then be asked for the prefix for the panorama output.\n\nYou may need to start the stitching in the batch processor\n PTBatcherGUI if it doesn't start automatically."),
+                        MainFrame::Get()->getProjectName().c_str()
+                    )
+                );
+            };
             if(dlg.ShowModal())
             {
                 if(XRCCTRL(dlg, "stitch_dont_show_checkbox", wxCheckBox)->IsChecked())
@@ -1669,7 +1700,7 @@ bool PanoPanel::CheckGoodSize()
         return false;
     };
     wxString message;
-    unsigned long long int area = ((unsigned long int) cropped_region.width()) * ((unsigned long int) cropped_region.height());
+    const unsigned long long area = (static_cast<unsigned long long>(cropped_region.width()) * cropped_region.height());
     // Argh, more than half a gigapixel!
     if (area > 500000000)
     {
