@@ -119,6 +119,9 @@ public:
     void BlenderChanged(wxCommandEvent & e);
     void OnBlenderOptions(wxCommandEvent & e);
 
+    void OnEdgeFillChanged(wxCommandEvent& e);
+    void OnEdgeFillOptions(wxCommandEvent& e);
+
     // File format options
     void FileFormatChanged(wxCommandEvent & e);
     void HDRFileFormatChanged(wxCommandEvent & e);
@@ -195,6 +198,7 @@ public:
     wxChoice    * m_FusionChoice;
     wxChoice    * m_HDRMergeChoice;
     wxChoice    * m_BlenderChoice;
+    wxChoice    * m_edgeFillChoice;
     wxButton    * m_StitchButton;
     wxButton    * m_CalcHFOVButton;
     wxButton    * m_CalcOptWidthButton;
