@@ -692,6 +692,12 @@ void PreferencesDialog::UpdateDisplayData(int panel)
         MY_CHOICE_VAL("prefs_misc_hdr_mapping", cfg->Read(wxT("/ImageCache/Mapping"), HUGIN_IMGCACHE_MAPPING_FLOAT));
         //MY_CHOICE_VAL("prefs_misc_hdr_range", cfg->Read(wxT("/ImageCache/Range"), HUGIN_IMGCACHE_RANGE));
 
+        int val = wxConfigBase::Get()->Read(wxT("/CPEditorPanel/MagnifierWidth"), 61l);
+        val = hugin_utils::floori((val - 61) / 20);
+        val = std::min(val, 3);
+        XRCCTRL(*this, "prefs_misc_magnifier_width", wxChoice)->SetSelection(val);
+
+
         MY_SPIN_VAL("prefs_ft_TemplateSize",
                     cfg->Read(wxT("/Finetune/TemplateSize"),HUGIN_FT_TEMPLATE_SIZE));
         MY_SPIN_VAL("prefs_ft_SearchAreaPercent",cfg->Read(wxT("/Finetune/SearchAreaPercent"),
@@ -901,6 +907,7 @@ void PreferencesDialog::OnRestoreDefaults(wxCommandEvent& e)
             // hdr
             cfg->Write(wxT("/ImageCache/Mapping"), HUGIN_IMGCACHE_MAPPING_FLOAT);
             //cfg->Write(wxT("/ImageCache/Range"), HUGIN_IMGCACHE_RANGE);
+            cfg->Write(wxT("/CPEditorPanel/MagnifierWidth"), 61l);
             // Fine tune settings
             cfg->Write(wxT("/Finetune/SearchAreaPercent"), HUGIN_FT_SEARCH_AREA_PERCENT);
             cfg->Write(wxT("/Finetune/TemplateSize"), HUGIN_FT_TEMPLATE_SIZE);
@@ -997,6 +1004,7 @@ void PreferencesDialog::UpdateConfigData()
     // hdr display
     cfg->Write(wxT("/ImageCache/Mapping"),MY_G_CHOICE_VAL("prefs_misc_hdr_mapping"));
     //cfg->Write(wxT("/ImageCache/Range"),MY_G_CHOICE_VAL("prefs_misc_hdr_range"));
+    cfg->Write(wxT("/CPEditorPanel/MagnifierWidth"), MY_G_CHOICE_VAL("prefs_misc_magnifier_width") * 20 + 61l);
 
     // Fine tune settings
     cfg->Write(wxT("/Finetune/SearchAreaPercent"), MY_G_SPIN_VAL("prefs_ft_SearchAreaPercent"));
