@@ -24,6 +24,7 @@
 
 #include "Tool.h"
 #include <set>
+#include <vector>
 
 class GLPreviewFrame;
 
@@ -42,7 +43,14 @@ class GLPreviewFrame;
 class PreviewIdentifyTool : public Tool
 {
 public:
-    PreviewIdentifyTool(ToolHelper *helper, GLPreviewFrame *owner);
+    /** constructor
+      @param helper pointer to ToolHelper class for managing Tool notifications
+      @param owner pointer to GLPreviewFrame, needed for updating the color of the image buttons
+      @param showNumbers true, if the image number should be shown above the images,
+        this image show code works only for the preview, not for the panosphere and mosaic plane
+        so pass the correct parameter depending on the underlying GLRenderer/GLViewer class
+    */
+    PreviewIdentifyTool(ToolHelper *helper, GLPreviewFrame *owner, bool showNumbers);
     ~PreviewIdentifyTool();
     void Activate();
     void ImagesUnderMouseChangedEvent();
@@ -75,24 +83,31 @@ private:
     static unsigned int circle_border_tex;
     /// OpenGL texture name for the rectangular border texture.
     static unsigned int rectangle_border_tex;
+    /// OpenGL texture name for the font texture
+    static unsigned int font_tex;
+    /// OpenGL call list id for font
+    static unsigned int font_list;
+    /// glyph width for font
+    static std::vector<int> m_glyphWidth;
+
     /// Set of image numbers of the images we are displaying highlighted.
-    std::set<unsigned int> image_set;
-    GLPreviewFrame *preview_frame;
+    std::set<unsigned int> m_image_set;
+    GLPreviewFrame *m_preview_frame;
     /// The image the user last placed their mouse over the button for
-    unsigned int mouse_over_image;
-    bool mouse_is_over_button;
+    unsigned int m_mouse_over_image;
+    bool m_mouse_is_over_button;
 
     void StopUpdating();
     void ContinueUpdating();
 
-    bool stopUpdating;
+    bool m_stopUpdating;
     //user has clicked and is holding left button while over panorama
-    bool holdLeft;
+    bool m_holdLeft;
     
-    bool holdControl;
+    bool m_holdControl;
 
-    bool constantOn;
-    
+    bool m_constantOn;
+    bool m_showNumbers;
 };
 
 #endif
