@@ -37,8 +37,8 @@ protected:
 
     bool createTexture();
 
-    bool texture_created;
-    unsigned int texture_num;
+    static bool texture_created;
+    static unsigned int texture_num;
 
     MeshManager::MeshInfo * mesh_info;
 
@@ -66,8 +66,6 @@ public:
     void Activate();
     explicit PanosphereOverviewProjectionGridTool(PanosphereOverviewToolHelper *helper) : PanosphereOverviewTool(helper), ProjectionGridTool(helper) {}
 
-    void createMesh();
-
     void AfterDrawImagesBackEvent();
     void BeforeDrawImagesBackEvent();
 
