@@ -599,11 +599,13 @@ RawImportDialog::RawImportDialog(wxWindow *parent, HuginBase::Panorama* pano, st
     wxXmlResource::Get()->LoadDialog(this, parent, wxT("import_raw_dialog"));
 
 #ifdef __WXMSW__
-    wxIcon myIcon(huginApp::Get()->GetXRCPath() + wxT("data/hugin.ico"),wxBITMAP_TYPE_ICO);
+    wxIconBundle myIcons(huginApp::Get()->GetXRCPath() + wxT("data/hugin.ico"),wxBITMAP_TYPE_ICO);
+    SetIcons(myIcons);
 #else
     wxIcon myIcon(huginApp::Get()->GetXRCPath() + wxT("data/hugin.png"),wxBITMAP_TYPE_PNG);
-#endif
     SetIcon(myIcon);
+#endif
+
     RestoreFramePosition(this, "RawImportDialog");
     wxConfigBase* config = wxConfig::Get();
     // dcraw
