@@ -20,6 +20,9 @@
  *
  */
 
+#ifdef _WIN32
+#include "wx/msw/wrapwin.h"
+#endif
 #include <math.h>
 #include <iostream>
 
@@ -47,6 +50,7 @@
 // supported OpenGL version on all platforms.
 #include <GL/glew.h>
 #include <wx/platform.h>
+#include <wx/display.h>
 
 #ifdef __WXMAC__
 #include <OpenGL/gl.h>
@@ -58,8 +62,11 @@
 
 // for loading preview images
 #include "wx/mstream.h"
-#include "exiv2/exiv2.hpp"
-#include "exiv2/preview.hpp"
+#ifdef _WIN32
+// workaround for a conflict between exiv2 and wxWidgets/CMake built
+#define HAVE_PID_T 1
+#endif
+#include <exiv2/exiv2.hpp>
 
 TextureManager::TextureManager(HuginBase::Panorama *pano, ViewState *view_state_in)
 {
@@ -472,11 +479,20 @@ void TextureManager::SetPhotometricCorrect(bool state)
 
 unsigned int TextureManager::GetMaxTotalTexels()
 {
-    // TODO: cut off at a sensible value for available hardware, otherwise set
-    // to something like 4 times the size of the screen.
-    // The value is guestimated as good for 1024*512 view where each point is
+    static int displaySize = 0;
+    if (displaySize == 0)
+    {
+        // check the resolution of all displays and use the biggest one
+        for (size_t i = 0; i < wxDisplay::GetCount(); ++i)
+        {
+            const wxRect currentDisplaySize = wxDisplay(i).GetGeometry();
+            displaySize = std::max(displaySize, currentDisplaySize.GetWidth() * currentDisplaySize.GetHeight());
+        };
+    };
+    // set to something like 4 times the size of the screen.
+    // The value is guestimated as good for a view where each point is
     // covered by 4 images.
-    return 2097152;
+    return 4 * displaySize;
     // Note: since we use mipmaps, the amount of actual maximum of pixels stored
     // will be 4/3 of this value. It should use a maximum of 8MB of video memory
     // for 8 bits per channel rgb images, 12MB if we include a mask.
@@ -742,7 +758,11 @@ void TextureManager::TextureInfo::DefineLevels(int min,
         GLubyte* placeholder_image;
         size_t placeholderWidth = 64;
         size_t placeholderHeight = 64;
+#if defined EXIV2_VERSION && EXIV2_TEST_VERSION(0,27,99)
+        Exiv2::Image::UniquePtr image;
+#else
         Exiv2::Image::AutoPtr image;
+#endif
         bool hasPreview = false;
         try
         {
@@ -785,21 +805,31 @@ void TextureManager::TextureInfo::DefineLevels(int min,
                 wxImage rawImage;
                 Exiv2::PreviewImage previewImage = previews->getPreviewImage(lists[previewIndex]);
                 wxMemoryInputStream stream(previewImage.pData(), previewImage.size());
-                rawImage.LoadFile(stream, wxString(previewImage.mimeType().c_str(), wxConvLocal), -1);
-                placeholderWidth = rawImage.GetWidth();
-                placeholderHeight = rawImage.GetHeight();
-                placeholder_image = new GLubyte[placeholderWidth * placeholderHeight * 4];
-                size_t index = 0;
-                for (size_t y = 0; y < placeholderHeight; ++y)
+                // disable logging for loading preview images
+                wxLog::EnableLogging(false);
+                if (rawImage.LoadFile(stream, wxString(previewImage.mimeType().c_str(), wxConvLocal), -1))
                 {
-                    for (size_t x = 0; x < placeholderWidth; ++x)
+                    placeholderWidth = rawImage.GetWidth();
+                    placeholderHeight = rawImage.GetHeight();
+                    placeholder_image = new GLubyte[placeholderWidth * placeholderHeight * 4];
+                    size_t index = 0;
+                    for (size_t y = 0; y < placeholderHeight; ++y)
                     {
-                        placeholder_image[index++] = rawImage.GetRed(x, y);
-                        placeholder_image[index++] = rawImage.GetGreen(x, y);
-                        placeholder_image[index++] = rawImage.GetBlue(x, y);
-                        placeholder_image[index++] = 63;
+                        for (size_t x = 0; x < placeholderWidth; ++x)
+                        {
+                            placeholder_image[index++] = rawImage.GetRed(x, y);
+                            placeholder_image[index++] = rawImage.GetGreen(x, y);
+                            placeholder_image[index++] = rawImage.GetBlue(x, y);
+                            placeholder_image[index++] = 63;
+                        };
                     };
+                }
+                else
+                {
+                    hasPreview = false;
                 };
+                // re-enable logging
+                wxLog::EnableLogging(true);
             };
         };
         if (!hasPreview)
@@ -910,8 +940,16 @@ void TextureManager::TextureInfo::DefineLevels(int min,
             // setup photometric transform for this image type
             // this corrects for response curve, white balance, exposure and
             // radial vignetting
+            HuginBase::SrcPanoImage tempSrcImg(src_img);
+            // for linear float image reset response type 
+            // because ImageCache returns already modified image information 
+            // depending on settings in the preferences
+            if (entry->imageFloat->size().area() > 0 && tempSrcImg.getResponseType() == HuginBase::SrcPanoImage::RESPONSE_LINEAR)
+            {
+                tempSrcImg.setResponseType(HuginBase::SrcPanoImage::RESPONSE_EMOR);
+            }
             HuginBase::Photometric::InvResponseTransform < unsigned char, double >
-                invResponse(src_img);
+                invResponse(tempSrcImg);
             // Assume LDR for now.
             // if (m_destImg.outputMode == PanoramaOptions::OUTPUT_LDR) {
             // select exposure and response curve for LDR output
@@ -924,7 +962,7 @@ void TextureManager::TextureInfo::DefineLevels(int min,
             vigra_ext::EMoR::createEMoRLUT(m_viewState->GetSrcImage(0)->getEMoRParams(), outLut);
             vigra_ext::enforceMonotonicity(outLut);
             invResponse.setOutput(1.0 / pow(2.0, dest_img.outputExposureValue),
-                outLut, 255.0);
+                outLut, 255.0, dest_img.outputRangeCompression);
             /*} else {
                // HDR output. not sure how that would be handled by the opengl
                // preview, though. It might be possible to apply a logarithmic
