@@ -54,6 +54,7 @@
 #include "hugin/HtmlWindow.h"
 #include "hugin/treelistctrl.h"
 #include "hugin/ImagesTree.h"
+#include "hugin/SplitButton.h"
 
 #include "base_wx/platform.h"
 #include "base_wx/huginConfig.h"
@@ -336,6 +337,7 @@ bool huginApp::OnInit()
     wxXmlResource::Get()->AddHandler(new wxcode::wxTreeListCtrlXmlHandler());
     wxXmlResource::Get()->AddHandler(new ImagesTreeCtrlXmlHandler());
     wxXmlResource::Get()->AddHandler(new CPListCtrlXmlHandler());
+    wxXmlResource::Get()->AddHandler(new SplitButtonXmlHandler());
 
     // load XRC files
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("cp_list_frame.xrc"));
@@ -377,6 +379,8 @@ bool huginApp::OnInit()
 #ifdef __WXMSW__
     frame->SendSizeEvent();
 #if wxCHECK_VERSION(3,1,0)
+// wxUSE_TASKBARBUTTON 1 is default, nevertheless check that the feature has not been deactivated by the user, otherwise issue a warning
+#if wxUSE_TASKBARBUTTON
     wxTaskBarJumpList jumpList;
     wxFileName exeFile(wxStandardPaths::Get().GetExecutablePath());
     exeFile.SetName("PTBatcherGUI");
@@ -391,6 +395,13 @@ bool huginApp::OnInit()
         _("Opens Calibrate_lens_gui, a simple GUI for lens calibration"),
         exeFile.GetFullPath(), 0);
     jumpList.GetTasks().Append(item2);
+#else
+  #if defined _MSC_VER
+    #pragma message("Warning: huginApp.cpp - wxWidgets is compiled without support for taskbar buttons. Some features have therefore disabled.")
+  #else
+    #warning "Warning: huginApp.cpp - wxWidgets is compiled without support for taskbar buttons. Some features have therefore disabled."
+  #endif
+#endif
 #endif
 #endif
     // init help system
