@@ -155,12 +155,14 @@ BatchFrame::BatchFrame(wxLocale* locale, wxString xrc)
     m_iconNormal = wxIcon(m_xrcPrefix + wxT("data/ptbatcher.ico"), wxBITMAP_TYPE_ICO);
     m_iconRunning = wxIcon(m_xrcPrefix + wxT("data/ptbatcher_running.ico"), wxBITMAP_TYPE_ICO);
     m_iconPaused = wxIcon(m_xrcPrefix + wxT("data/ptbatcher_pause.ico"), wxBITMAP_TYPE_ICO);
+    wxIconBundle myIcons(m_xrcPrefix + wxT("data/ptbatcher.ico"), wxBITMAP_TYPE_ICO);
+    SetIcons(myIcons);
 #else
     m_iconNormal = wxIcon(m_xrcPrefix + wxT("data/ptbatcher.png"), wxBITMAP_TYPE_PNG);
     m_iconRunning = wxIcon(m_xrcPrefix + wxT("data/ptbatcher_running.png"), wxBITMAP_TYPE_PNG);
     m_iconPaused = wxIcon(m_xrcPrefix + wxT("data/ptbatcher_pause.png"), wxBITMAP_TYPE_PNG);
-#endif
     SetIcon(m_iconNormal);
+#endif
 
     m_batch = new Batch(this);
     if(wxGetKeyState(WXK_COMMAND))
@@ -1220,7 +1222,11 @@ void BatchFrame::RestoreSize()
     }
     else
     {
-        SetSize(600,400);
+#if wxCHECK_VERSION(3,1,0)
+        SetSize(this->FromDIP(wxSize(600,400)));
+#else
+        SetSize(600, 400);
+#endif
     }
 
     if(max==1)
@@ -1282,7 +1288,7 @@ void BatchFrame::OnProgress(wxCommandEvent& e)
 
 void BatchFrame::UpdateTaskBarProgressBar()
 {
-#if defined __WXMSW__ && wxCHECK_VERSION(3,1,0)
+#if defined __WXMSW__ && wxCHECK_VERSION(3,1,0) && wxUSE_TASKBARBUTTON
     // provide also a feedback in task bar if available
     if (IsShown())
     {
