@@ -61,7 +61,7 @@ BEGIN_EVENT_TABLE(FindPanoDialog,wxDialog)
     EVT_CLOSE(FindPanoDialog::OnClose)
 END_EVENT_TABLE()
 
-bool SortFilename::operator()(const HuginBase::SrcPanoImage* img1, const HuginBase::SrcPanoImage* img2)
+bool SortFilename::operator()(const HuginBase::SrcPanoImage* img1, const HuginBase::SrcPanoImage* img2) const
 {
     return doj::alphanum_comp(img1->getFilename(),img2->getFilename())<0;
 };
@@ -76,11 +76,12 @@ FindPanoDialog::FindPanoDialog(BatchFrame* batchframe, wxString xrcPrefix)
     wxXmlResource::Get()->LoadDialog(this,batchframe,wxT("find_pano_dialog"));
 
 #ifdef __WXMSW__
-    wxIcon myIcon(xrcPrefix+ wxT("data/ptbatcher.ico"),wxBITMAP_TYPE_ICO);
+    wxIconBundle myIcons(xrcPrefix+ wxT("data/ptbatcher.ico"),wxBITMAP_TYPE_ICO);
+    SetIcons(myIcons);
 #else
     wxIcon myIcon(xrcPrefix + wxT("data/ptbatcher.png"),wxBITMAP_TYPE_PNG);
-#endif
     SetIcon(myIcon);
+#endif
     m_batchframe=batchframe;
     m_isRunning=false;
     m_stopped=false;
@@ -633,6 +634,10 @@ bool PossiblePano::BelongsTo(HuginBase::SrcPanoImage* img, const wxTimeSpan max_
     {
         return false;
     }
+    if (fabs(m_cropfactor - img->getCropFactor()) > 0.01)
+    {
+        return false;
+    }
     if(m_size!=img->getSize())
     {
         return false;
@@ -667,6 +672,7 @@ void PossiblePano::AddSrcPanoImage(HuginBase::SrcPanoImage* img)
         m_camera=img->getExifModel();
         m_lens=img->getExifLens();
         m_focallength=img->getExifFocalLength();
+        m_cropfactor = img->getCropFactor();
         m_size=img->getSize();
         m_dt_start=GetDateTime(img);
         m_dt_end=m_dt_start;
