@@ -472,9 +472,9 @@ std::string GetUserAppDataDir()
 #else
 #ifdef USE_XDG_DIRS
     char *xdgDataDir = getenv("XDG_DATA_HOME");
-    if (strlen(xdgDataDir) == 0)
+    if (xdgDataDir == NULL || strlen(xdgDataDir) == 0)
     {
-        // no XDG_DATA_HOME enviroment variable set
+        // no XDG_DATA_HOME enviroment variable set or empty variable
         // use $HOME/.local/share instead
         const  std::string homeDir = GetHomeDir();
         if (homeDir.empty())
