@@ -52,16 +52,29 @@
 
 namespace HuginBase {
 
-void SrcPanoImage::resize(const vigra::Size2D & sz)
+void SrcPanoImage::resize(const vigra::Size2D & sz, VariableMap* potentialLinkedVars)
 {
         // TODO: check if images have the same orientation.
         // calculate scaling ratio
         const double scale = (double) sz.x / m_Size.getData().x;
         
         // center shift
-        m_RadialDistortionCenterShift.setData(m_RadialDistortionCenterShift.getData() * scale);
-        m_Shear.setData(m_Shear.getData() * scale);
-        
+        if (potentialLinkedVars != nullptr)
+        {
+            // pointer to VariableMap given, can be used to update linked variables later
+            // otherwise linked variables could not be correct updated, e.g. in apply template
+            potentialLinkedVars->insert(std::make_pair("d", Variable("d", m_RadialDistortionCenterShift.getData().x * scale)));
+            potentialLinkedVars->insert(std::make_pair("e", Variable("e", m_RadialDistortionCenterShift.getData().y * scale)));
+            potentialLinkedVars->insert(std::make_pair("g", Variable("g", m_Shear.getData().x * scale)));
+            potentialLinkedVars->insert(std::make_pair("t", Variable("t", m_Shear.getData().y * scale)));
+        }
+        else
+        {
+            // directly update the image variables
+            m_RadialDistortionCenterShift.setData(m_RadialDistortionCenterShift.getData() * scale);
+            m_Shear.setData(m_Shear.getData() * scale);
+        };
+
         // crop
         // ensure the scaled rectangle is inside the new image size
         switch (m_CropMode.getData())
@@ -88,7 +101,16 @@ void SrcPanoImage::resize(const vigra::Size2D & sz)
         
         m_Size.setData(sz);
         // vignetting correction
-        m_RadialVigCorrCenterShift.setData(m_RadialVigCorrCenterShift.getData() *scale);
+        if (potentialLinkedVars != nullptr)
+        {
+            // see comment under center shift above
+            potentialLinkedVars->insert(std::make_pair("Vx", Variable("Vx", m_RadialVigCorrCenterShift.getData().x * scale)));
+            potentialLinkedVars->insert(std::make_pair("Vy", Variable("Vy", m_RadialVigCorrCenterShift.getData().y * scale)));
+        }
+        else
+        {
+            m_RadialVigCorrCenterShift.setData(m_RadialVigCorrCenterShift.getData() * scale);
+        };
         // resize masks
         MaskPolygonVector scaledMasks=m_Masks.getData();
         for(unsigned int i=0;i<scaledMasks.size();i++)
