@@ -210,8 +210,11 @@ public:
     /** "resize" image,
      *  adjusts all distortion coefficients for usage with a source image
      *  of size @p size
+     *  @p potentialLinkedVars contains a map of potential linked variables which needs an update afterwards
+     *     to correctly handle the linkage, when passing a nullptr these variables are directly updated in 
+     *     this function
      */
-    void resize(const vigra::Size2D & size);
+    void resize(const vigra::Size2D & size, VariableMap* potentialLinkedVars);
 
     /** check if a coordinate is inside the source image
      */
