@@ -115,6 +115,29 @@ namespace vigra_ext
         };
     }; // namespace detail
     
+    // blend 2 images with Poisson blending
+    // labels contains the map which images should deliver the input, see comment in MergeImages for the values
+    template <class ImageType, class MaskType>
+    void PoissonBlend(ImageType& image1, const ImageType& image2, const MaskType& mask2, const vigra::BImage& labels, const vigra::Point2D& offsetPoint, const bool doWrap)
+    {
+        // mark edges in labels for solving Poisson equation with different boundary conditions
+        vigra::ImagePyramid<vigra::Int8Image> seams;
+        const int minLength = 8;
+        vigra_ext::poisson::BuildSeamPyramid(labels, seams, minLength);
+        // create gradient map
+        typedef typename vigra::NumericTraits<typename ImageType::PixelType>::RealPromote ImageRealPixelType;
+        vigra::BasicImage<ImageRealPixelType> gradient(image2.size());
+        vigra::BasicImage<ImageRealPixelType> target(image2.size());
+        // build gradient map with special handling of both boundary conditions
+        vigra_ext::poisson::BuildGradientMap(image1, image2, mask2, seams[0], gradient, offsetPoint, doWrap);
+        // we start with the values of the image2 as begin
+        vigra::omp::copyImageIf(vigra::srcImageRange(image2), vigra::srcImage(seams[0], vigra_ext::poisson::MaskGreaterAccessor<vigra::Int8>(2)), vigra::destImage(target));
+        // solve poisson equation
+        vigra_ext::poisson::Multigrid(target, gradient, seams, minLength, 0.01f, 500, doWrap);
+        // copy result back into output
+        vigra::omp::copyImageIf(vigra::srcImageRange(target), vigra::srcImage(seams[0], vigra_ext::poisson::MaskGreaterAccessor<vigra::Int8>(2)), vigra::destImage(image1, offsetPoint));
+    }
+
     template <class ImageType, class MaskType>
     void MergeImages(ImageType& image1, MaskType& mask1, const ImageType& image2, const MaskType& mask2, const vigra::Diff2D offset, const bool wrap, const bool hardSeam)
     {
@@ -138,7 +161,7 @@ namespace vigra_ext
         vigra::ArrayOfRegionStatistics<vigra::FindBoundingRectangle> roi(3);
         vigra::inspectTwoImages(vigra::srcIterRange<vigra::Diff2D>(vigra::Diff2D(0, 0), labels.size()), vigra::srcImage(labels), roi);
         // handle some special cases
-        if (roi.regions[3].size().area() == 0)
+        if (roi.regions[3].size().area() == 0 && hardSeam)
         {
             // images do not overlap, simply copy image2 into image1
             vigra::copyImageIf(vigra::srcImageRange(image2), vigra::srcImage(mask2), vigra::destImage(image1, offsetPoint, image1.accessor()));
@@ -253,22 +276,7 @@ namespace vigra_ext
             // 0: no image here
             // 1: use information from image 1
             // 5: use information from image 2
-            // mark edges in labels for solving Poisson equation with different boundary conditions
-            vigra::ImagePyramid<vigra::Int8Image> seams;
-            const int minLength = 8;
-            vigra_ext::poisson::BuildSeamPyramid(labels, seams, minLength);
-            // create gradient map
-            typedef typename vigra::NumericTraits<typename ImageType::PixelType>::RealPromote ImageRealPixelType;
-            vigra::BasicImage<ImageRealPixelType> gradient(image2.size());
-            vigra::BasicImage<ImageRealPixelType> target(image2.size());
-            // build gradient map with special handling of both boundary conditions
-            vigra_ext::poisson::BuildGradientMap(image1, image2, mask2, seams[0], gradient, offsetPoint, doWrap);
-            // we start with the values of the image2 as begin
-            vigra::omp::copyImageIf(vigra::srcImageRange(image2), vigra::srcImage(seams[0], vigra_ext::poisson::MaskGreaterAccessor<vigra::Int8>(2)), vigra::destImage(target));
-            // solve poisson equation
-            vigra_ext::poisson::Multigrid(target, gradient, seams, minLength, 0.01f, 500, doWrap);
-            // copy result back into output
-            vigra::omp::copyImageIf(vigra::srcImageRange(target), vigra::srcImage(seams[0], vigra_ext::poisson::MaskGreaterAccessor<vigra::Int8>(2)), vigra::destImage(image1, offsetPoint));
+            PoissonBlend(image1, image2, mask2, labels, offsetPoint, doWrap);
         };
     };
 
