@@ -39,6 +39,7 @@
 #include "KDTreeImpl.h"
 */
 #include "Utils.h"
+#include "hugin_utils/stl_utils.h"
 #include "Tracer.h"
 
 #include <algorithms/nona/ComputeImageROI.h>
@@ -1187,8 +1188,15 @@ bool PanoDetector::FilterMatchesInPair(MatchData& ioMatchData, const PanoDetecto
     for (size_t i = 0; i < ioMatchData._matches.size(); ++i)
     {
         lfeat::PointMatchPtr& aM = ioMatchData._matches[i];
+        HuginBase::ControlPoint cp(ioMatchData._i1->_number, aM->_img1_x, aM->_img1_y,
+            ioMatchData._i2->_number, aM->_img2_x, aM->_img2_y);
+        if (set_contains(iPanoDetector._cpsHashSet, cp.getCPString()))
+        {
+            // match already exits, skipping
+            continue;
+        }
         aSieve.insert(aM, (int)((aM->_img1_x - aMinX) * aXF), (int)((aM->_img1_y - aMinY) * aYF));
-    }
+    };
 
     // pull remaining values from the sieve
     ioMatchData._matches.clear();
@@ -1215,7 +1223,6 @@ void PanoDetector::writeOutput()
 
     aOut << "# pto project file generated by Hugin's cpfind" << std::endl << std::endl;
 
-    _panoramaInfo->removeDuplicateCtrlPoints();
     AppBase::DocumentData::ReadWriteError err = _panoramaInfo->writeData(aOut);
     if (err != AppBase::DocumentData::SUCCESSFUL)
     {
