@@ -231,6 +231,8 @@ int main(int argc, char* argv[])
             pano.setSrcImage(i, img);
         }
     }
+    // update optimize vector, if switch is set to manual nothing is done
+    pano.updateOptimizeVector();
 
     if(pano.getNrOfCtrlPoints()==0 && (doPairwise || doAutoOpt || doNormalOpt))
     {
