@@ -100,6 +100,7 @@ static void usage(const char* name)
          << "      --save-intermediate-images  saves also the intermediate" << std::endl
          << "                   images (only when output is TIFF, PNG or JPEG)" << std::endl
          << "      --intermediate-suffix=SUFFIX  suffix for intermediate images" << std::endl
+         << "      --final-suffix=SUFFIX  suffix for the final image" << std::endl
          << "      --create-exposure-layers  create all exposure layers" << std::endl
          << "                   (this will always use TIFF)" << std::endl
          << "      --clip-exposure[=lower cutoff:upper cutoff]" << std::endl
@@ -139,6 +140,7 @@ int main(int argc, char* argv[])
         IGNOREEXPOSURE=1000,
         SAVEINTERMEDIATEIMAGES,
         INTERMEDIATESUFFIX,
+        FINALSUFFIX,
         EXPOSURELAYERS,
         MASKCLIPEXPOSURE,
         SEAMMODE,
@@ -150,6 +152,7 @@ int main(int argc, char* argv[])
         { "ignore-exposure", no_argument, NULL, IGNOREEXPOSURE },
         { "save-intermediate-images", no_argument, NULL, SAVEINTERMEDIATEIMAGES },
         { "intermediate-suffix", required_argument, NULL, INTERMEDIATESUFFIX },
+        { "final-suffix", required_argument, NULL, FINALSUFFIX },
         { "compression", required_argument, NULL, 'z' },
         { "create-exposure-layers", no_argument, NULL, EXPOSURELAYERS },
         { "clip-exposure", optional_argument, NULL, MASKCLIPEXPOSURE },
@@ -212,6 +215,9 @@ int main(int argc, char* argv[])
             case INTERMEDIATESUFFIX:
                 HuginBase::Nona::SetAdvancedOption(advOptions, "saveIntermediateImagesSuffix", std::string(optarg));
                 break;
+            case FINALSUFFIX:
+                HuginBase::Nona::SetAdvancedOption(advOptions, "saveFinalImageSuffix", std::string(optarg));
+                break;
             case EXPOSURELAYERS:
                 createExposureLayers = true;
                 break;
