@@ -64,10 +64,12 @@ static void usage(const char* name)
          << "                                AUTO: calculate optimal canvas size" << std::endl
          << "                                num%: scales the optimal size by given percent" << std::endl
          << "                                WIDTHxHEIGHT: set to given size" << std::endl
-         << "    --crop=AUTO|AUTOHDR|left,right,top,bottom  Sets the crop rectangle" << std::endl
+         << "    --crop=AUTO|AUTOHDR|left,right,top,bottom|left,right,top,bottom%" << std::endl
+         << "                                Sets the crop rectangle" << std::endl
          << "                                AUTO: autocrop panorama" << std::endl
          << "                                AUTOHDR: autocrop HDR panorama" << std::endl
          << "                                left,right,top,bottom: to given size" << std::endl
+         << "                                left,right,top,bottom%: to size relative to canvas" << std::endl
          << "    --output-exposure=AUTO|num  Sets the output exposure value to mean" << std::endl
          << "                                exposure (AUTO) or to given value" << std::endl
          << "                                Prefix number with r for relativ change" << std::endl
@@ -177,6 +179,8 @@ int main(int argc, char* argv[])
     int newHeight=-1;
     int outputCroppedTiff=-1;
     vigra::Rect2D newROI(0,0,0,0);
+    hugin_utils::FDiff2D newRoiRelativeLeftTop(-1.0, -1.0);
+    hugin_utils::FDiff2D newRoiRelativeRightBottom(-1.0, -1.0);
     bool doFit=false;
     bool doStraighten=false;
     bool doCenter=false;
@@ -365,25 +369,55 @@ int main(int argc, char* argv[])
                 }
                 else
                 {
-                    int left, right, top, bottom;
-                    int n=sscanf(optarg, "%d,%d,%d,%d", &left, &right, &top, &bottom);
-                    if (n==4)
+                    const int pos = param.find("%");
+                    if (pos != std::string::npos)
                     {
-                        if(right>left && bottom>top && left>=0 && top>=0)
-                        {
-                            newROI.setUpperLeft(vigra::Point2D(left,top));
-                            newROI.setLowerRight(vigra::Point2D(right,bottom));
+                        // parse relative values
+                        param = param.substr(0, pos);
+                        double left, right, top, bottom;
+                        const int n = sscanf(param.c_str(), "%lf,%lf,%lf,%lf", &left, &right, &top, &bottom);
+                        if(n==4)
+                        { 
+                            if (right > left && bottom > top && left >= 0.0 && top >= 0.0 && right<=100.0 && bottom<=100.0)
+                            {
+                                // check values, 0..100 %
+                                newRoiRelativeLeftTop = hugin_utils::FDiff2D(left, top);
+                                newRoiRelativeRightBottom = hugin_utils::FDiff2D(right, bottom);
+                            }
+                            else
+                            {
+                                std::cerr << hugin_utils::stripPath(argv[0]) << ": Invalid crop area" << std::endl;
+                                return 1;
+                            };
                         }
                         else
                         {
-                            std::cerr << hugin_utils::stripPath(argv[0]) << ": Invalid crop area" << std::endl;
+                            std::cerr << hugin_utils::stripPath(argv[0]) << ": Could not parse crop values" << std::endl;
                             return 1;
                         };
                     }
                     else
                     {
-                        std::cerr << hugin_utils::stripPath(argv[0]) << ": Could not parse crop values" << std::endl;
-                        return 1;
+                        int left, right, top, bottom;
+                        int n = sscanf(optarg, "%d,%d,%d,%d", &left, &right, &top, &bottom);
+                        if (n == 4)
+                        {
+                            if (right > left && bottom > top && left >= 0 && top >= 0)
+                            {
+                                newROI.setUpperLeft(vigra::Point2D(left, top));
+                                newROI.setLowerRight(vigra::Point2D(right, bottom));
+                            }
+                            else
+                            {
+                                std::cerr << hugin_utils::stripPath(argv[0]) << ": Invalid crop area" << std::endl;
+                                return 1;
+                            };
+                        }
+                        else
+                        {
+                            std::cerr << hugin_utils::stripPath(argv[0]) << ": Could not parse crop values" << std::endl;
+                            return 1;
+                        };
                     };
                 };
                 break;
@@ -1026,9 +1060,21 @@ int main(int argc, char* argv[])
     {
         HuginBase::PanoramaOptions opt = pano.getOptions();
         opt.setROI(newROI);
-        std::cout << "Set crop size to " << newROI.left() << "," << newROI.right() << "," << newROI.top() << "," << newROI.bottom() << std::endl;
+        std::cout << "Set crop size to " << opt.getROI().left() << "," << opt.getROI().right() << "," << opt.getROI().top() << "," << opt.getROI().bottom() << std::endl;
         pano.setOptions(opt);
     };
+    if (newRoiRelativeLeftTop.x > -1 && newRoiRelativeRightBottom.x > -1)
+    {
+        HuginBase::PanoramaOptions opt = pano.getOptions();
+        opt.setROI(vigra::Rect2D(
+            opt.getWidth() * newRoiRelativeLeftTop.x / 100.0, 
+            opt.getHeight() * newRoiRelativeLeftTop.y / 100.0,
+            opt.getWidth() * newRoiRelativeRightBottom.x / 100.0,
+            opt.getHeight() * newRoiRelativeRightBottom.y / 100.0
+        ));
+        std::cout << "Set crop size to " << opt.getROI().left() << "," << opt.getROI().right() << "," << opt.getROI().top() << "," << opt.getROI().bottom() << std::endl;
+        pano.setOptions(opt);
+    }
     //setting interpolation method
     if (interpolation>=0)
     {
