@@ -154,6 +154,7 @@ int main(int argc, char* argv[])
     }
 
     // check image sizes, and correct parameters if required.
+    HuginBase::VariableMapVector vars(newPano.getNrOfImages());
     for (unsigned int i = 0; i < newPano.getNrOfImages(); i++)
     {
         // check if image size is correct
@@ -165,10 +166,19 @@ int main(int argc, char* argv[])
         if (oldSrcImg.getSize() != newSrcImg.getSize())
         {
             // adjust size properly.
-            newSrcImg.resize(oldSrcImg.getSize());
+            newSrcImg.resize(oldSrcImg.getSize(), &vars[i]);
         }
         newPano.setSrcImage(i, newSrcImg);
     }
+    // now update all possible linked variables
+    for (unsigned int i = 0; i < newPano.getNrOfImages(); ++i)
+    {
+        if (!vars[i].empty())
+        {
+            newPano.updateVariables(i, vars[i]);
+        };
+    };
+
     // keep old control points.
     newPano.setCtrlPoints(pano.getCtrlPoints());
 
