@@ -235,6 +235,9 @@ void UnLinkVars(HuginBase::Panorama& pano, Parser::ParseVarVec parseVec, bool li
             };
         };
     };
+    // update optimize variables, e.g. the link has changed and the new unlinked variables need
+    // to be added to optimize vector
+    pano.updateOptimizeVector();
 };
 
 // parse number, take an optional % sign into account
@@ -724,6 +727,7 @@ int main(int argc, char* argv[])
             std::cout << "Setting optimizer anchor to image " << anchor << std::endl;
             opts.optimizeReferenceImage = anchor;
             pano.setOptions(opts);
+            pano.updateOptimizeVector();
         };
     };
     // update color anchor
@@ -736,9 +740,10 @@ int main(int argc, char* argv[])
         else
         {
             HuginBase::PanoramaOptions opts = pano.getOptions();
-            std::cout << "Setting color anchor to image " << anchor << std::endl;
+            std::cout << "Setting color anchor to image " << colorAnchor << std::endl;
             opts.colorReferenceImage = colorAnchor;
             pano.setOptions(opts);
+            pano.updateOptimizeVector();
         };
     };
     // update optimzer vector
